from ...tl.mtproto_request import MTProtoRequest


class ChannelForbidden(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    channelForbidden#8537784f flags:# broadcast:flags.5?true megagroup:flags.8?true id:int access_hash:long title:string = Chat"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x8537784f

    def __init__(self, id, access_hash, title, broadcast=None, megagroup=None):
        """
        :param broadcast: Telegram type: «true».
        :param megagroup: Telegram type: «true».
        :param id: Telegram type: «int».
        :param access_hash: Telegram type: «long».
        :param title: Telegram type: «string».

        Constructor for Chat: Instance of either ChatEmpty, Chat, ChatForbidden, Channel, ChannelForbidden.
        """
        super().__init__()

        self.broadcast = broadcast
        self.megagroup = megagroup
        self.id = id
        self.access_hash = access_hash
        self.title = title

    def on_send(self, writer):
        writer.write_int(ChannelForbidden.constructor_id, signed=False)
        # Calculate the flags. This equals to those flag arguments which are NOT None
        flags = 0
        flags |= (1 << 5) if self.broadcast else 0
        flags |= (1 << 8) if self.megagroup else 0
        writer.write_int(flags)

        writer.write_int(self.id)
        writer.write_long(self.access_hash)
        writer.tgwrite_string(self.title)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return ChannelForbidden(None, None, None, None, None)

    def on_response(self, reader):
        flags = reader.read_int()

        if (flags & (1 << 5)) != 0:
            self.broadcast = True  # Arbitrary not-None value, no need to read since it is a flag

        if (flags & (1 << 8)) != 0:
            self.megagroup = True  # Arbitrary not-None value, no need to read since it is a flag

        self.id = reader.read_int()
        self.access_hash = reader.read_long()
        self.title = reader.tgread_string()

    def __repr__(self):
        return 'channelForbidden#8537784f flags:# broadcast:flags.5?true megagroup:flags.8?true id:int access_hash:long title:string = Chat'

    def __str__(self):
        return '(channelForbidden (ID: 0x8537784f) = (broadcast={}, megagroup={}, id={}, access_hash={}, title={}))'.format(str(self.broadcast), str(self.megagroup), str(self.id), str(self.access_hash), str(self.title))



from ...tl.mtproto_request import MTProtoRequest


class UserFull(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    userFull#0f220f3f flags:# blocked:flags.0?true phone_calls_available:flags.4?true phone_calls_private:flags.5?true user:User about:flags.1?string link:contacts.Link profile_photo:flags.2?Photo notify_settings:PeerNotifySettings bot_info:flags.3?BotInfo common_chats_count:int = UserFull"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0xf220f3f

    def __init__(self, user, link, notify_settings, common_chats_count, blocked=None, phone_calls_available=None, phone_calls_private=None, about=None, profile_photo=None, bot_info=None):
        """
        :param blocked: Telegram type: «true».
        :param phone_calls_available: Telegram type: «true».
        :param phone_calls_private: Telegram type: «true».
        :param user: Telegram type: «User».
        :param about: Telegram type: «string».
        :param link: Telegram type: «contacts.Link».
        :param profile_photo: Telegram type: «Photo».
        :param notify_settings: Telegram type: «PeerNotifySettings».
        :param bot_info: Telegram type: «BotInfo».
        :param common_chats_count: Telegram type: «int».

        Constructor for UserFull: Instance of UserFull.
        """
        super().__init__()

        self.blocked = blocked
        self.phone_calls_available = phone_calls_available
        self.phone_calls_private = phone_calls_private
        self.user = user
        self.about = about
        self.link = link
        self.profile_photo = profile_photo
        self.notify_settings = notify_settings
        self.bot_info = bot_info
        self.common_chats_count = common_chats_count

    def on_send(self, writer):
        writer.write_int(UserFull.constructor_id, signed=False)
        # Calculate the flags. This equals to those flag arguments which are NOT None
        flags = 0
        flags |= (1 << 0) if self.blocked else 0
        flags |= (1 << 4) if self.phone_calls_available else 0
        flags |= (1 << 5) if self.phone_calls_private else 0
        flags |= (1 << 1) if self.about else 0
        flags |= (1 << 2) if self.profile_photo else 0
        flags |= (1 << 3) if self.bot_info else 0
        writer.write_int(flags)

        self.user.on_send(writer)
        if self.about:
            writer.tgwrite_string(self.about)

        self.link.on_send(writer)
        if self.profile_photo:
            self.profile_photo.on_send(writer)

        self.notify_settings.on_send(writer)
        if self.bot_info:
            self.bot_info.on_send(writer)

        writer.write_int(self.common_chats_count)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return UserFull(None, None, None, None, None, None, None, None, None, None)

    def on_response(self, reader):
        flags = reader.read_int()

        if (flags & (1 << 0)) != 0:
            self.blocked = True  # Arbitrary not-None value, no need to read since it is a flag

        if (flags & (1 << 4)) != 0:
            self.phone_calls_available = True  # Arbitrary not-None value, no need to read since it is a flag

        if (flags & (1 << 5)) != 0:
            self.phone_calls_private = True  # Arbitrary not-None value, no need to read since it is a flag

        self.user = reader.tgread_object()
        if (flags & (1 << 1)) != 0:
            self.about = reader.tgread_string()

        self.link = reader.tgread_object()
        if (flags & (1 << 2)) != 0:
            self.profile_photo = reader.tgread_object()

        self.notify_settings = reader.tgread_object()
        if (flags & (1 << 3)) != 0:
            self.bot_info = reader.tgread_object()

        self.common_chats_count = reader.read_int()

    def __repr__(self):
        return 'userFull#0f220f3f flags:# blocked:flags.0?true phone_calls_available:flags.4?true phone_calls_private:flags.5?true user:User about:flags.1?string link:contacts.Link profile_photo:flags.2?Photo notify_settings:PeerNotifySettings bot_info:flags.3?BotInfo common_chats_count:int = UserFull'

    def __str__(self):
        return '(userFull (ID: 0xf220f3f) = (blocked={}, phone_calls_available={}, phone_calls_private={}, user={}, about={}, link={}, profile_photo={}, notify_settings={}, bot_info={}, common_chats_count={}))'.format(str(self.blocked), str(self.phone_calls_available), str(self.phone_calls_private), str(self.user), str(self.about), str(self.link), str(self.profile_photo), str(self.notify_settings), str(self.bot_info), str(self.common_chats_count))



from ...tl.mtproto_request import MTProtoRequest


class Config(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    config#cb601684 flags:# phonecalls_enabled:flags.1?true date:date expires:date test_mode:Bool this_dc:int dc_options:Vector<DcOption> chat_size_max:int megagroup_size_max:int forwarded_count_max:int online_update_period_ms:int offline_blur_timeout_ms:int offline_idle_timeout_ms:int online_cloud_timeout_ms:int notify_cloud_delay_ms:int notify_default_delay_ms:int chat_big_size:int push_chat_period_ms:int push_chat_limit:int saved_gifs_limit:int edit_time_limit:int rating_e_decay:int stickers_recent_limit:int tmp_sessions:flags.0?int pinned_dialogs_count_max:int call_receive_timeout_ms:int call_ring_timeout_ms:int call_connect_timeout_ms:int call_packet_timeout_ms:int me_url_prefix:string disabled_features:Vector<DisabledFeature> = Config"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0xcb601684

    def __init__(self, date, expires, test_mode, this_dc, dc_options, chat_size_max, megagroup_size_max, forwarded_count_max, online_update_period_ms, offline_blur_timeout_ms, offline_idle_timeout_ms, online_cloud_timeout_ms, notify_cloud_delay_ms, notify_default_delay_ms, chat_big_size, push_chat_period_ms, push_chat_limit, saved_gifs_limit, edit_time_limit, rating_e_decay, stickers_recent_limit, pinned_dialogs_count_max, call_receive_timeout_ms, call_ring_timeout_ms, call_connect_timeout_ms, call_packet_timeout_ms, me_url_prefix, disabled_features, phonecalls_enabled=None, tmp_sessions=None):
        """
        :param phonecalls_enabled: Telegram type: «true».
        :param date: Telegram type: «date».
        :param expires: Telegram type: «date».
        :param test_mode: Telegram type: «Bool».
        :param this_dc: Telegram type: «int».
        :param dc_options: Telegram type: «DcOption». Must be a list.
        :param chat_size_max: Telegram type: «int».
        :param megagroup_size_max: Telegram type: «int».
        :param forwarded_count_max: Telegram type: «int».
        :param online_update_period_ms: Telegram type: «int».
        :param offline_blur_timeout_ms: Telegram type: «int».
        :param offline_idle_timeout_ms: Telegram type: «int».
        :param online_cloud_timeout_ms: Telegram type: «int».
        :param notify_cloud_delay_ms: Telegram type: «int».
        :param notify_default_delay_ms: Telegram type: «int».
        :param chat_big_size: Telegram type: «int».
        :param push_chat_period_ms: Telegram type: «int».
        :param push_chat_limit: Telegram type: «int».
        :param saved_gifs_limit: Telegram type: «int».
        :param edit_time_limit: Telegram type: «int».
        :param rating_e_decay: Telegram type: «int».
        :param stickers_recent_limit: Telegram type: «int».
        :param tmp_sessions: Telegram type: «int».
        :param pinned_dialogs_count_max: Telegram type: «int».
        :param call_receive_timeout_ms: Telegram type: «int».
        :param call_ring_timeout_ms: Telegram type: «int».
        :param call_connect_timeout_ms: Telegram type: «int».
        :param call_packet_timeout_ms: Telegram type: «int».
        :param me_url_prefix: Telegram type: «string».
        :param disabled_features: Telegram type: «DisabledFeature». Must be a list.

        Constructor for Config: Instance of Config.
        """
        super().__init__()

        self.phonecalls_enabled = phonecalls_enabled
        self.date = date
        self.expires = expires
        self.test_mode = test_mode
        self.this_dc = this_dc
        self.dc_options = dc_options
        self.chat_size_max = chat_size_max
        self.megagroup_size_max = megagroup_size_max
        self.forwarded_count_max = forwarded_count_max
        self.online_update_period_ms = online_update_period_ms
        self.offline_blur_timeout_ms = offline_blur_timeout_ms
        self.offline_idle_timeout_ms = offline_idle_timeout_ms
        self.online_cloud_timeout_ms = online_cloud_timeout_ms
        self.notify_cloud_delay_ms = notify_cloud_delay_ms
        self.notify_default_delay_ms = notify_default_delay_ms
        self.chat_big_size = chat_big_size
        self.push_chat_period_ms = push_chat_period_ms
        self.push_chat_limit = push_chat_limit
        self.saved_gifs_limit = saved_gifs_limit
        self.edit_time_limit = edit_time_limit
        self.rating_e_decay = rating_e_decay
        self.stickers_recent_limit = stickers_recent_limit
        self.tmp_sessions = tmp_sessions
        self.pinned_dialogs_count_max = pinned_dialogs_count_max
        self.call_receive_timeout_ms = call_receive_timeout_ms
        self.call_ring_timeout_ms = call_ring_timeout_ms
        self.call_connect_timeout_ms = call_connect_timeout_ms
        self.call_packet_timeout_ms = call_packet_timeout_ms
        self.me_url_prefix = me_url_prefix
        self.disabled_features = disabled_features

    def on_send(self, writer):
        writer.write_int(Config.constructor_id, signed=False)
        # Calculate the flags. This equals to those flag arguments which are NOT None
        flags = 0
        flags |= (1 << 1) if self.phonecalls_enabled else 0
        flags |= (1 << 0) if self.tmp_sessions else 0
        writer.write_int(flags)

        writer.tgwrite_date(self.date)
        writer.tgwrite_date(self.expires)
        writer.tgwrite_bool(self.test_mode)
        writer.write_int(self.this_dc)
        writer.write_int(0x1cb5c415, signed=False)  # Vector's constructor ID
        writer.write_int(len(self.dc_options))
        for dc_options_item in self.dc_options:
            dc_options_item.on_send(writer)

        writer.write_int(self.chat_size_max)
        writer.write_int(self.megagroup_size_max)
        writer.write_int(self.forwarded_count_max)
        writer.write_int(self.online_update_period_ms)
        writer.write_int(self.offline_blur_timeout_ms)
        writer.write_int(self.offline_idle_timeout_ms)
        writer.write_int(self.online_cloud_timeout_ms)
        writer.write_int(self.notify_cloud_delay_ms)
        writer.write_int(self.notify_default_delay_ms)
        writer.write_int(self.chat_big_size)
        writer.write_int(self.push_chat_period_ms)
        writer.write_int(self.push_chat_limit)
        writer.write_int(self.saved_gifs_limit)
        writer.write_int(self.edit_time_limit)
        writer.write_int(self.rating_e_decay)
        writer.write_int(self.stickers_recent_limit)
        if self.tmp_sessions:
            writer.write_int(self.tmp_sessions)

        writer.write_int(self.pinned_dialogs_count_max)
        writer.write_int(self.call_receive_timeout_ms)
        writer.write_int(self.call_ring_timeout_ms)
        writer.write_int(self.call_connect_timeout_ms)
        writer.write_int(self.call_packet_timeout_ms)
        writer.tgwrite_string(self.me_url_prefix)
        writer.write_int(0x1cb5c415, signed=False)  # Vector's constructor ID
        writer.write_int(len(self.disabled_features))
        for disabled_features_item in self.disabled_features:
            disabled_features_item.on_send(writer)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return Config(None, None, None, None, None, None, None, None, None, None, None, None, None, None, None, None, None, None, None, None, None, None, None, None, None, None, None, None, None, None)

    def on_response(self, reader):
        flags = reader.read_int()

        if (flags & (1 << 1)) != 0:
            self.phonecalls_enabled = True  # Arbitrary not-None value, no need to read since it is a flag

        self.date = reader.tgread_date()
        self.expires = reader.tgread_date()
        self.test_mode = reader.tgread_bool()
        self.this_dc = reader.read_int()
        reader.read_int()  # Vector's constructor ID
        self.dc_options = []  # Initialize an empty list
        dc_options_len = reader.read_int()
        for _ in range(dc_options_len):
            dc_options_item = reader.tgread_object()
            self.dc_options.append(dc_options_item)

        self.chat_size_max = reader.read_int()
        self.megagroup_size_max = reader.read_int()
        self.forwarded_count_max = reader.read_int()
        self.online_update_period_ms = reader.read_int()
        self.offline_blur_timeout_ms = reader.read_int()
        self.offline_idle_timeout_ms = reader.read_int()
        self.online_cloud_timeout_ms = reader.read_int()
        self.notify_cloud_delay_ms = reader.read_int()
        self.notify_default_delay_ms = reader.read_int()
        self.chat_big_size = reader.read_int()
        self.push_chat_period_ms = reader.read_int()
        self.push_chat_limit = reader.read_int()
        self.saved_gifs_limit = reader.read_int()
        self.edit_time_limit = reader.read_int()
        self.rating_e_decay = reader.read_int()
        self.stickers_recent_limit = reader.read_int()
        if (flags & (1 << 0)) != 0:
            self.tmp_sessions = reader.read_int()

        self.pinned_dialogs_count_max = reader.read_int()
        self.call_receive_timeout_ms = reader.read_int()
        self.call_ring_timeout_ms = reader.read_int()
        self.call_connect_timeout_ms = reader.read_int()
        self.call_packet_timeout_ms = reader.read_int()
        self.me_url_prefix = reader.tgread_string()
        reader.read_int()  # Vector's constructor ID
        self.disabled_features = []  # Initialize an empty list
        disabled_features_len = reader.read_int()
        for _ in range(disabled_features_len):
            disabled_features_item = reader.tgread_object()
            self.disabled_features.append(disabled_features_item)

    def __repr__(self):
        return 'config#cb601684 flags:# phonecalls_enabled:flags.1?true date:date expires:date test_mode:Bool this_dc:int dc_options:Vector<DcOption> chat_size_max:int megagroup_size_max:int forwarded_count_max:int online_update_period_ms:int offline_blur_timeout_ms:int offline_idle_timeout_ms:int online_cloud_timeout_ms:int notify_cloud_delay_ms:int notify_default_delay_ms:int chat_big_size:int push_chat_period_ms:int push_chat_limit:int saved_gifs_limit:int edit_time_limit:int rating_e_decay:int stickers_recent_limit:int tmp_sessions:flags.0?int pinned_dialogs_count_max:int call_receive_timeout_ms:int call_ring_timeout_ms:int call_connect_timeout_ms:int call_packet_timeout_ms:int me_url_prefix:string disabled_features:Vector<DisabledFeature> = Config'

    def __str__(self):
        return '(config (ID: 0xcb601684) = (phonecalls_enabled={}, date={}, expires={}, test_mode={}, this_dc={}, dc_options={}, chat_size_max={}, megagroup_size_max={}, forwarded_count_max={}, online_update_period_ms={}, offline_blur_timeout_ms={}, offline_idle_timeout_ms={}, online_cloud_timeout_ms={}, notify_cloud_delay_ms={}, notify_default_delay_ms={}, chat_big_size={}, push_chat_period_ms={}, push_chat_limit={}, saved_gifs_limit={}, edit_time_limit={}, rating_e_decay={}, stickers_recent_limit={}, tmp_sessions={}, pinned_dialogs_count_max={}, call_receive_timeout_ms={}, call_ring_timeout_ms={}, call_connect_timeout_ms={}, call_packet_timeout_ms={}, me_url_prefix={}, disabled_features={}))'.format(str(self.phonecalls_enabled), str(self.date), str(self.expires), str(self.test_mode), str(self.this_dc), None if not self.dc_options else [str(_) for _ in self.dc_options], str(self.chat_size_max), str(self.megagroup_size_max), str(self.forwarded_count_max), str(self.online_update_period_ms), str(self.offline_blur_timeout_ms), str(self.offline_idle_timeout_ms), str(self.online_cloud_timeout_ms), str(self.notify_cloud_delay_ms), str(self.notify_default_delay_ms), str(self.chat_big_size), str(self.push_chat_period_ms), str(self.push_chat_limit), str(self.saved_gifs_limit), str(self.edit_time_limit), str(self.rating_e_decay), str(self.stickers_recent_limit), str(self.tmp_sessions), str(self.pinned_dialogs_count_max), str(self.call_receive_timeout_ms), str(self.call_ring_timeout_ms), str(self.call_connect_timeout_ms), str(self.call_packet_timeout_ms), str(self.me_url_prefix), None if not self.disabled_features else [str(_) for _ in self.disabled_features])



from ...tl.mtproto_request import MTProtoRequest


class UpdateContactRegistered(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    updateContactRegistered#2575bbb9 user_id:int date:date = Update"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x2575bbb9

    def __init__(self, user_id, date):
        """
        :param user_id: Telegram type: «int».
        :param date: Telegram type: «date».

        Constructor for Update: Instance of either UpdateNewMessage, UpdateMessageID, UpdateDeleteMessages, UpdateUserTyping, UpdateChatUserTyping, UpdateChatParticipants, UpdateUserStatus, UpdateUserName, UpdateUserPhoto, UpdateContactRegistered, UpdateContactLink, UpdateNewEncryptedMessage, UpdateEncryptedChatTyping, UpdateEncryption, UpdateEncryptedMessagesRead, UpdateChatParticipantAdd, UpdateChatParticipantDelete, UpdateDcOptions, UpdateUserBlocked, UpdateNotifySettings, UpdateServiceNotification, UpdatePrivacy, UpdateUserPhone, UpdateReadHistoryInbox, UpdateReadHistoryOutbox, UpdateWebPage, UpdateReadMessagesContents, UpdateChannelTooLong, UpdateChannel, UpdateNewChannelMessage, UpdateReadChannelInbox, UpdateDeleteChannelMessages, UpdateChannelMessageViews, UpdateChatAdmins, UpdateChatParticipantAdmin, UpdateNewStickerSet, UpdateStickerSetsOrder, UpdateStickerSets, UpdateSavedGifs, UpdateBotInlineQuery, UpdateBotInlineSend, UpdateEditChannelMessage, UpdateChannelPinnedMessage, UpdateBotCallbackQuery, UpdateEditMessage, UpdateInlineBotCallbackQuery, UpdateReadChannelOutbox, UpdateDraftMessage, UpdateReadFeaturedStickers, UpdateRecentStickers, UpdateConfig, UpdatePtsChanged, UpdateChannelWebPage, UpdateDialogPinned, UpdatePinnedDialogs, UpdateBotWebhookJSON, UpdateBotWebhookJSONQuery, UpdateBotShippingQuery, UpdateBotPrecheckoutQuery, UpdatePhoneCall.
        """
        super().__init__()

        self.user_id = user_id
        self.date = date

    def on_send(self, writer):
        writer.write_int(UpdateContactRegistered.constructor_id, signed=False)
        writer.write_int(self.user_id)
        writer.tgwrite_date(self.date)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return UpdateContactRegistered(None, None)

    def on_response(self, reader):
        self.user_id = reader.read_int()
        self.date = reader.tgread_date()

    def __repr__(self):
        return 'updateContactRegistered#2575bbb9 user_id:int date:date = Update'

    def __str__(self):
        return '(updateContactRegistered (ID: 0x2575bbb9) = (user_id={}, date={}))'.format(str(self.user_id), str(self.date))



from ...tl.mtproto_request import MTProtoRequest


class TopPeer(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    topPeer#edcdc05b peer:Peer rating:double = TopPeer"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0xedcdc05b

    def __init__(self, peer, rating):
        """
        :param peer: Telegram type: «Peer».
        :param rating: Telegram type: «double».

        Constructor for TopPeer: Instance of TopPeer.
        """
        super().__init__()

        self.peer = peer
        self.rating = rating

    def on_send(self, writer):
        writer.write_int(TopPeer.constructor_id, signed=False)
        self.peer.on_send(writer)
        writer.write_double(self.rating)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return TopPeer(None, None)

    def on_response(self, reader):
        self.peer = reader.tgread_object()
        self.rating = reader.read_double()

    def __repr__(self):
        return 'topPeer#edcdc05b peer:Peer rating:double = TopPeer'

    def __str__(self):
        return '(topPeer (ID: 0xedcdc05b) = (peer={}, rating={}))'.format(str(self.peer), str(self.rating))



from ...tl.mtproto_request import MTProtoRequest


class EncryptedMessage(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    encryptedMessage#ed18c118 random_id:long chat_id:int date:date bytes:bytes file:EncryptedFile = EncryptedMessage"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0xed18c118

    def __init__(self, random_id, chat_id, date, bytes, file):
        """
        :param random_id: Telegram type: «long».
        :param chat_id: Telegram type: «int».
        :param date: Telegram type: «date».
        :param bytes: Telegram type: «bytes».
        :param file: Telegram type: «EncryptedFile».

        Constructor for EncryptedMessage: Instance of either EncryptedMessage, EncryptedMessageService.
        """
        super().__init__()

        self.random_id = random_id
        self.chat_id = chat_id
        self.date = date
        self.bytes = bytes
        self.file = file

    def on_send(self, writer):
        writer.write_int(EncryptedMessage.constructor_id, signed=False)
        writer.write_long(self.random_id)
        writer.write_int(self.chat_id)
        writer.tgwrite_date(self.date)
        writer.tgwrite_bytes(self.bytes)
        self.file.on_send(writer)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return EncryptedMessage(None, None, None, None, None)

    def on_response(self, reader):
        self.random_id = reader.read_long()
        self.chat_id = reader.read_int()
        self.date = reader.tgread_date()
        self.bytes = reader.tgread_bytes()
        self.file = reader.tgread_object()

    def __repr__(self):
        return 'encryptedMessage#ed18c118 random_id:long chat_id:int date:date bytes:bytes file:EncryptedFile = EncryptedMessage'

    def __str__(self):
        return '(encryptedMessage (ID: 0xed18c118) = (random_id={}, chat_id={}, date={}, bytes={}, file={}))'.format(str(self.random_id), str(self.chat_id), str(self.date), str(self.bytes), str(self.file))



from ....tl.mtproto_request import MTProtoRequest


class SaveDraftRequest(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    messages.saveDraft#bc39e14b flags:# no_webpage:flags.1?true reply_to_msg_id:flags.0?int peer:InputPeer message:string entities:flags.3?Vector<MessageEntity> = Bool"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0xbc39e14b

    def __init__(self, peer, message, no_webpage=None, reply_to_msg_id=None, entities=None):
        """
        :param no_webpage: Telegram type: «true».
        :param reply_to_msg_id: Telegram type: «int».
        :param peer: Telegram type: «InputPeer».
        :param message: Telegram type: «string».
        :param entities: Telegram type: «MessageEntity». Must be a list.

        :returns Bool: This type has no constructors.
        """
        super().__init__()
        self.result = None
        self.confirmed = True  # Confirmed by default

        self.no_webpage = no_webpage
        self.reply_to_msg_id = reply_to_msg_id
        self.peer = peer
        self.message = message
        self.entities = entities

    def on_send(self, writer):
        writer.write_int(SaveDraftRequest.constructor_id, signed=False)
        # Calculate the flags. This equals to those flag arguments which are NOT None
        flags = 0
        flags |= (1 << 1) if self.no_webpage else 0
        flags |= (1 << 0) if self.reply_to_msg_id else 0
        flags |= (1 << 3) if self.entities else 0
        writer.write_int(flags)

        if self.reply_to_msg_id:
            writer.write_int(self.reply_to_msg_id)

        self.peer.on_send(writer)
        writer.tgwrite_string(self.message)
        if self.entities:
            writer.write_int(0x1cb5c415, signed=False)  # Vector's constructor ID
            writer.write_int(len(self.entities))
            for entities_item in self.entities:
                if entities_item:
                    entities_item.on_send(writer)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return SaveDraftRequest(None, None, None, None, None)

    def on_response(self, reader):
        self.result = reader.tgread_object()

    def __repr__(self):
        return 'messages.saveDraft#bc39e14b flags:# no_webpage:flags.1?true reply_to_msg_id:flags.0?int peer:InputPeer message:string entities:flags.3?Vector<MessageEntity> = Bool'

    def __str__(self):
        return '(messages.saveDraft (ID: 0xbc39e14b) = (no_webpage={}, reply_to_msg_id={}, peer={}, message={}, entities={}))'.format(str(self.no_webpage), str(self.reply_to_msg_id), str(self.peer), str(self.message), None if not self.entities else [str(_) for _ in self.entities])



from ....tl.mtproto_request import MTProtoRequest


class ReuploadCdnFileRequest(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    upload.reuploadCdnFile#2e7a2020 file_token:bytes request_token:bytes = Bool"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x2e7a2020

    def __init__(self, file_token, request_token):
        """
        :param file_token: Telegram type: «bytes».
        :param request_token: Telegram type: «bytes».

        :returns Bool: This type has no constructors.
        """
        super().__init__()
        self.result = None
        self.confirmed = True  # Confirmed by default

        self.file_token = file_token
        self.request_token = request_token

    def on_send(self, writer):
        writer.write_int(ReuploadCdnFileRequest.constructor_id, signed=False)
        writer.tgwrite_bytes(self.file_token)
        writer.tgwrite_bytes(self.request_token)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return ReuploadCdnFileRequest(None, None)

    def on_response(self, reader):
        self.result = reader.tgread_object()

    def __repr__(self):
        return 'upload.reuploadCdnFile#2e7a2020 file_token:bytes request_token:bytes = Bool'

    def __str__(self):
        return '(upload.reuploadCdnFile (ID: 0x2e7a2020) = (file_token={}, request_token={}))'.format(str(self.file_token), str(self.request_token))



from ....tl.mtproto_request import MTProtoRequest


class GetDialogsRequest(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    messages.getDialogs#191ba9c5 flags:# exclude_pinned:flags.0?true offset_date:date offset_id:int offset_peer:InputPeer limit:int = messages.Dialogs"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x191ba9c5

    def __init__(self, offset_date, offset_id, offset_peer, limit, exclude_pinned=None):
        """
        :param exclude_pinned: Telegram type: «true».
        :param offset_date: Telegram type: «date».
        :param offset_id: Telegram type: «int».
        :param offset_peer: Telegram type: «InputPeer».
        :param limit: Telegram type: «int».

        :returns messages.Dialogs: Instance of either Dialogs, DialogsSlice.
        """
        super().__init__()
        self.result = None
        self.confirmed = True  # Confirmed by default

        self.exclude_pinned = exclude_pinned
        self.offset_date = offset_date
        self.offset_id = offset_id
        self.offset_peer = offset_peer
        self.limit = limit

    def on_send(self, writer):
        writer.write_int(GetDialogsRequest.constructor_id, signed=False)
        # Calculate the flags. This equals to those flag arguments which are NOT None
        flags = 0
        flags |= (1 << 0) if self.exclude_pinned else 0
        writer.write_int(flags)

        writer.tgwrite_date(self.offset_date)
        writer.write_int(self.offset_id)
        self.offset_peer.on_send(writer)
        writer.write_int(self.limit)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return GetDialogsRequest(None, None, None, None, None)

    def on_response(self, reader):
        self.result = reader.tgread_object()

    def __repr__(self):
        return 'messages.getDialogs#191ba9c5 flags:# exclude_pinned:flags.0?true offset_date:date offset_id:int offset_peer:InputPeer limit:int = messages.Dialogs'

    def __str__(self):
        return '(messages.getDialogs (ID: 0x191ba9c5) = (exclude_pinned={}, offset_date={}, offset_id={}, offset_peer={}, limit={}))'.format(str(self.exclude_pinned), str(self.offset_date), str(self.offset_id), str(self.offset_peer), str(self.limit))



from ...tl.mtproto_request import MTProtoRequest


class UpdateBotCallbackQuery(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    updateBotCallbackQuery#e73547e1 flags:# query_id:long user_id:int peer:Peer msg_id:int chat_instance:long data:flags.0?bytes game_short_name:flags.1?string = Update"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0xe73547e1

    def __init__(self, query_id, user_id, peer, msg_id, chat_instance, data=None, game_short_name=None):
        """
        :param query_id: Telegram type: «long».
        :param user_id: Telegram type: «int».
        :param peer: Telegram type: «Peer».
        :param msg_id: Telegram type: «int».
        :param chat_instance: Telegram type: «long».
        :param data: Telegram type: «bytes».
        :param game_short_name: Telegram type: «string».

        Constructor for Update: Instance of either UpdateNewMessage, UpdateMessageID, UpdateDeleteMessages, UpdateUserTyping, UpdateChatUserTyping, UpdateChatParticipants, UpdateUserStatus, UpdateUserName, UpdateUserPhoto, UpdateContactRegistered, UpdateContactLink, UpdateNewEncryptedMessage, UpdateEncryptedChatTyping, UpdateEncryption, UpdateEncryptedMessagesRead, UpdateChatParticipantAdd, UpdateChatParticipantDelete, UpdateDcOptions, UpdateUserBlocked, UpdateNotifySettings, UpdateServiceNotification, UpdatePrivacy, UpdateUserPhone, UpdateReadHistoryInbox, UpdateReadHistoryOutbox, UpdateWebPage, UpdateReadMessagesContents, UpdateChannelTooLong, UpdateChannel, UpdateNewChannelMessage, UpdateReadChannelInbox, UpdateDeleteChannelMessages, UpdateChannelMessageViews, UpdateChatAdmins, UpdateChatParticipantAdmin, UpdateNewStickerSet, UpdateStickerSetsOrder, UpdateStickerSets, UpdateSavedGifs, UpdateBotInlineQuery, UpdateBotInlineSend, UpdateEditChannelMessage, UpdateChannelPinnedMessage, UpdateBotCallbackQuery, UpdateEditMessage, UpdateInlineBotCallbackQuery, UpdateReadChannelOutbox, UpdateDraftMessage, UpdateReadFeaturedStickers, UpdateRecentStickers, UpdateConfig, UpdatePtsChanged, UpdateChannelWebPage, UpdateDialogPinned, UpdatePinnedDialogs, UpdateBotWebhookJSON, UpdateBotWebhookJSONQuery, UpdateBotShippingQuery, UpdateBotPrecheckoutQuery, UpdatePhoneCall.
        """
        super().__init__()

        self.query_id = query_id
        self.user_id = user_id
        self.peer = peer
        self.msg_id = msg_id
        self.chat_instance = chat_instance
        self.data = data
        self.game_short_name = game_short_name

    def on_send(self, writer):
        writer.write_int(UpdateBotCallbackQuery.constructor_id, signed=False)
        # Calculate the flags. This equals to those flag arguments which are NOT None
        flags = 0
        flags |= (1 << 0) if self.data else 0
        flags |= (1 << 1) if self.game_short_name else 0
        writer.write_int(flags)

        writer.write_long(self.query_id)
        writer.write_int(self.user_id)
        self.peer.on_send(writer)
        writer.write_int(self.msg_id)
        writer.write_long(self.chat_instance)
        if self.data:
            writer.tgwrite_bytes(self.data)

        if self.game_short_name:
            writer.tgwrite_string(self.game_short_name)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return UpdateBotCallbackQuery(None, None, None, None, None, None, None)

    def on_response(self, reader):
        flags = reader.read_int()

        self.query_id = reader.read_long()
        self.user_id = reader.read_int()
        self.peer = reader.tgread_object()
        self.msg_id = reader.read_int()
        self.chat_instance = reader.read_long()
        if (flags & (1 << 0)) != 0:
            self.data = reader.tgread_bytes()

        if (flags & (1 << 1)) != 0:
            self.game_short_name = reader.tgread_string()

    def __repr__(self):
        return 'updateBotCallbackQuery#e73547e1 flags:# query_id:long user_id:int peer:Peer msg_id:int chat_instance:long data:flags.0?bytes game_short_name:flags.1?string = Update'

    def __str__(self):
        return '(updateBotCallbackQuery (ID: 0xe73547e1) = (query_id={}, user_id={}, peer={}, msg_id={}, chat_instance={}, data={}, game_short_name={}))'.format(str(self.query_id), str(self.user_id), str(self.peer), str(self.msg_id), str(self.chat_instance), str(self.data), str(self.game_short_name))



from ...tl.mtproto_request import MTProtoRequest


class UpdateContactLink(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    updateContactLink#9d2e67c5 user_id:int my_link:ContactLink foreign_link:ContactLink = Update"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x9d2e67c5

    def __init__(self, user_id, my_link, foreign_link):
        """
        :param user_id: Telegram type: «int».
        :param my_link: Telegram type: «ContactLink».
        :param foreign_link: Telegram type: «ContactLink».

        Constructor for Update: Instance of either UpdateNewMessage, UpdateMessageID, UpdateDeleteMessages, UpdateUserTyping, UpdateChatUserTyping, UpdateChatParticipants, UpdateUserStatus, UpdateUserName, UpdateUserPhoto, UpdateContactRegistered, UpdateContactLink, UpdateNewEncryptedMessage, UpdateEncryptedChatTyping, UpdateEncryption, UpdateEncryptedMessagesRead, UpdateChatParticipantAdd, UpdateChatParticipantDelete, UpdateDcOptions, UpdateUserBlocked, UpdateNotifySettings, UpdateServiceNotification, UpdatePrivacy, UpdateUserPhone, UpdateReadHistoryInbox, UpdateReadHistoryOutbox, UpdateWebPage, UpdateReadMessagesContents, UpdateChannelTooLong, UpdateChannel, UpdateNewChannelMessage, UpdateReadChannelInbox, UpdateDeleteChannelMessages, UpdateChannelMessageViews, UpdateChatAdmins, UpdateChatParticipantAdmin, UpdateNewStickerSet, UpdateStickerSetsOrder, UpdateStickerSets, UpdateSavedGifs, UpdateBotInlineQuery, UpdateBotInlineSend, UpdateEditChannelMessage, UpdateChannelPinnedMessage, UpdateBotCallbackQuery, UpdateEditMessage, UpdateInlineBotCallbackQuery, UpdateReadChannelOutbox, UpdateDraftMessage, UpdateReadFeaturedStickers, UpdateRecentStickers, UpdateConfig, UpdatePtsChanged, UpdateChannelWebPage, UpdateDialogPinned, UpdatePinnedDialogs, UpdateBotWebhookJSON, UpdateBotWebhookJSONQuery, UpdateBotShippingQuery, UpdateBotPrecheckoutQuery, UpdatePhoneCall.
        """
        super().__init__()

        self.user_id = user_id
        self.my_link = my_link
        self.foreign_link = foreign_link

    def on_send(self, writer):
        writer.write_int(UpdateContactLink.constructor_id, signed=False)
        writer.write_int(self.user_id)
        self.my_link.on_send(writer)
        self.foreign_link.on_send(writer)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return UpdateContactLink(None, None, None)

    def on_response(self, reader):
        self.user_id = reader.read_int()
        self.my_link = reader.tgread_object()
        self.foreign_link = reader.tgread_object()

    def __repr__(self):
        return 'updateContactLink#9d2e67c5 user_id:int my_link:ContactLink foreign_link:ContactLink = Update'

    def __str__(self):
        return '(updateContactLink (ID: 0x9d2e67c5) = (user_id={}, my_link={}, foreign_link={}))'.format(str(self.user_id), str(self.my_link), str(self.foreign_link))



from ....tl.mtproto_request import MTProtoRequest


class DeleteHistoryRequest(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    messages.deleteHistory#1c015b09 flags:# just_clear:flags.0?true peer:InputPeer max_id:int = messages.AffectedHistory"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x1c015b09

    def __init__(self, peer, max_id, just_clear=None):
        """
        :param just_clear: Telegram type: «true».
        :param peer: Telegram type: «InputPeer».
        :param max_id: Telegram type: «int».

        :returns messages.AffectedHistory: Instance of AffectedHistory.
        """
        super().__init__()
        self.result = None
        self.confirmed = True  # Confirmed by default

        self.just_clear = just_clear
        self.peer = peer
        self.max_id = max_id

    def on_send(self, writer):
        writer.write_int(DeleteHistoryRequest.constructor_id, signed=False)
        # Calculate the flags. This equals to those flag arguments which are NOT None
        flags = 0
        flags |= (1 << 0) if self.just_clear else 0
        writer.write_int(flags)

        self.peer.on_send(writer)
        writer.write_int(self.max_id)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return DeleteHistoryRequest(None, None, None)

    def on_response(self, reader):
        self.result = reader.tgread_object()

    def __repr__(self):
        return 'messages.deleteHistory#1c015b09 flags:# just_clear:flags.0?true peer:InputPeer max_id:int = messages.AffectedHistory'

    def __str__(self):
        return '(messages.deleteHistory (ID: 0x1c015b09) = (just_clear={}, peer={}, max_id={}))'.format(str(self.just_clear), str(self.peer), str(self.max_id))



from ....tl.mtproto_request import MTProtoRequest


class ToggleDialogPinRequest(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    messages.toggleDialogPin#3289be6a flags:# pinned:flags.0?true peer:InputPeer = Bool"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x3289be6a

    def __init__(self, peer, pinned=None):
        """
        :param pinned: Telegram type: «true».
        :param peer: Telegram type: «InputPeer».

        :returns Bool: This type has no constructors.
        """
        super().__init__()
        self.result = None
        self.confirmed = True  # Confirmed by default

        self.pinned = pinned
        self.peer = peer

    def on_send(self, writer):
        writer.write_int(ToggleDialogPinRequest.constructor_id, signed=False)
        # Calculate the flags. This equals to those flag arguments which are NOT None
        flags = 0
        flags |= (1 << 0) if self.pinned else 0
        writer.write_int(flags)

        self.peer.on_send(writer)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return ToggleDialogPinRequest(None, None)

    def on_response(self, reader):
        self.result = reader.tgread_object()

    def __repr__(self):
        return 'messages.toggleDialogPin#3289be6a flags:# pinned:flags.0?true peer:InputPeer = Bool'

    def __str__(self):
        return '(messages.toggleDialogPin (ID: 0x3289be6a) = (pinned={}, peer={}))'.format(str(self.pinned), str(self.peer))



from ...tl.mtproto_request import MTProtoRequest


class FoundGifCached(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    foundGifCached#9c750409 url:string photo:Photo document:Document = FoundGif"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x9c750409

    def __init__(self, url, photo, document):
        """
        :param url: Telegram type: «string».
        :param photo: Telegram type: «Photo».
        :param document: Telegram type: «Document».

        Constructor for FoundGif: Instance of either FoundGif, FoundGifCached.
        """
        super().__init__()

        self.url = url
        self.photo = photo
        self.document = document

    def on_send(self, writer):
        writer.write_int(FoundGifCached.constructor_id, signed=False)
        writer.tgwrite_string(self.url)
        self.photo.on_send(writer)
        self.document.on_send(writer)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return FoundGifCached(None, None, None)

    def on_response(self, reader):
        self.url = reader.tgread_string()
        self.photo = reader.tgread_object()
        self.document = reader.tgread_object()

    def __repr__(self):
        return 'foundGifCached#9c750409 url:string photo:Photo document:Document = FoundGif'

    def __str__(self):
        return '(foundGifCached (ID: 0x9c750409) = (url={}, photo={}, document={}))'.format(str(self.url), str(self.photo), str(self.document))



from ...tl.mtproto_request import MTProtoRequest


class ExportedMessageLink(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    exportedMessageLink#1f486803 link:string = ExportedMessageLink"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x1f486803

    def __init__(self, link):
        """
        :param link: Telegram type: «string».

        Constructor for ExportedMessageLink: Instance of ExportedMessageLink.
        """
        super().__init__()

        self.link = link

    def on_send(self, writer):
        writer.write_int(ExportedMessageLink.constructor_id, signed=False)
        writer.tgwrite_string(self.link)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return ExportedMessageLink(None)

    def on_response(self, reader):
        self.link = reader.tgread_string()

    def __repr__(self):
        return 'exportedMessageLink#1f486803 link:string = ExportedMessageLink'

    def __str__(self):
        return '(exportedMessageLink (ID: 0x1f486803) = (link={}))'.format(str(self.link))



import os
from hashlib import sha1

from ..utils import BinaryWriter


class RSAServerKey:
    def __init__(self, fingerprint, m, e):
        self.fingerprint = fingerprint
        self.m = m
        self.e = e

    def encrypt(self, data, offset=None, length=None):
        """Encrypts the given data with the current key"""
        if offset is None:
            offset = 0
        if length is None:
            length = len(data)

        with BinaryWriter() as writer:
            # Write SHA
            writer.write(sha1(data[offset:offset + length]).digest())
            # Write data
            writer.write(data[offset:offset + length])
            # Add padding if required
            if length < 235:
                writer.write(os.urandom(235 - length))

            result = int.from_bytes(writer.get_bytes(), byteorder='big')
            result = pow(result, self.e, self.m)

            # If the result byte count is less than 256, since the byte order is big,
            # the non-used bytes on the left will be 0 and act as padding,
            # without need of any additional checks
            return int.to_bytes(
                result, length=256, byteorder='big', signed=False)


class RSA:
    _server_keys = {
        '216be86c022bb4c3': RSAServerKey('216be86c022bb4c3', int(
            'C150023E2F70DB7985DED064759CFECF0AF328E69A41DAF4D6F01B538135A6F9'
            '1F8F8B2A0EC9BA9720CE352EFCF6C5680FFC424BD634864902DE0B4BD6D49F4E'
            '580230E3AE97D95C8B19442B3C0A10D8F5633FECEDD6926A7F6DAB0DDB7D457F'
            '9EA81B8465FCD6FFFEED114011DF91C059CAEDAF97625F6C96ECC74725556934'
            'EF781D866B34F011FCE4D835A090196E9A5F0E4449AF7EB697DDB9076494CA5F'
            '81104A305B6DD27665722C46B60E5DF680FB16B210607EF217652E60236C255F'
            '6A28315F4083A96791D7214BF64C1DF4FD0DB1944FB26A2A57031B32EEE64AD1'
            '5A8BA68885CDE74A5BFC920F6ABF59BA5C75506373E7130F9042DA922179251F',
            16), int('010001', 16))
    }

    @staticmethod
    def encrypt(fingerprint, data, offset=None, length=None):
        """Encrypts the given data given a fingerprint"""
        if fingerprint.lower() not in RSA._server_keys:
            return None

        key = RSA._server_keys[fingerprint.lower()]
        return key.encrypt(data, offset, length)



from ...tl.mtproto_request import MTProtoRequest


class DcOption(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    dcOption#05d8c6cc flags:# ipv6:flags.0?true media_only:flags.1?true tcpo_only:flags.2?true cdn:flags.3?true id:int ip_address:string port:int = DcOption"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x5d8c6cc

    def __init__(self, id, ip_address, port, ipv6=None, media_only=None, tcpo_only=None, cdn=None):
        """
        :param ipv6: Telegram type: «true».
        :param media_only: Telegram type: «true».
        :param tcpo_only: Telegram type: «true».
        :param cdn: Telegram type: «true».
        :param id: Telegram type: «int».
        :param ip_address: Telegram type: «string».
        :param port: Telegram type: «int».

        Constructor for DcOption: Instance of DcOption.
        """
        super().__init__()

        self.ipv6 = ipv6
        self.media_only = media_only
        self.tcpo_only = tcpo_only
        self.cdn = cdn
        self.id = id
        self.ip_address = ip_address
        self.port = port

    def on_send(self, writer):
        writer.write_int(DcOption.constructor_id, signed=False)
        # Calculate the flags. This equals to those flag arguments which are NOT None
        flags = 0
        flags |= (1 << 0) if self.ipv6 else 0
        flags |= (1 << 1) if self.media_only else 0
        flags |= (1 << 2) if self.tcpo_only else 0
        flags |= (1 << 3) if self.cdn else 0
        writer.write_int(flags)

        writer.write_int(self.id)
        writer.tgwrite_string(self.ip_address)
        writer.write_int(self.port)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return DcOption(None, None, None, None, None, None, None)

    def on_response(self, reader):
        flags = reader.read_int()

        if (flags & (1 << 0)) != 0:
            self.ipv6 = True  # Arbitrary not-None value, no need to read since it is a flag

        if (flags & (1 << 1)) != 0:
            self.media_only = True  # Arbitrary not-None value, no need to read since it is a flag

        if (flags & (1 << 2)) != 0:
            self.tcpo_only = True  # Arbitrary not-None value, no need to read since it is a flag

        if (flags & (1 << 3)) != 0:
            self.cdn = True  # Arbitrary not-None value, no need to read since it is a flag

        self.id = reader.read_int()
        self.ip_address = reader.tgread_string()
        self.port = reader.read_int()

    def __repr__(self):
        return 'dcOption#05d8c6cc flags:# ipv6:flags.0?true media_only:flags.1?true tcpo_only:flags.2?true cdn:flags.3?true id:int ip_address:string port:int = DcOption'

    def __str__(self):
        return '(dcOption (ID: 0x5d8c6cc) = (ipv6={}, media_only={}, tcpo_only={}, cdn={}, id={}, ip_address={}, port={}))'.format(str(self.ipv6), str(self.media_only), str(self.tcpo_only), str(self.cdn), str(self.id), str(self.ip_address), str(self.port))



from ...tl.mtproto_request import MTProtoRequest


class InputStickerSetEmpty(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    inputStickerSetEmpty#ffb62b95  = InputStickerSet"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0xffb62b95

    def __init__(self):
        super().__init__()

    def on_send(self, writer):
        writer.write_int(InputStickerSetEmpty.constructor_id, signed=False)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return InputStickerSetEmpty()

    def on_response(self, reader):
        pass

    def __repr__(self):
        return 'inputStickerSetEmpty#ffb62b95  = InputStickerSet'

    def __str__(self):
        return '(inputStickerSetEmpty (ID: 0xffb62b95) = ())'.format()



from ...tl.mtproto_request import MTProtoRequest


class PageBlockVideo(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    pageBlockVideo#d9d71866 flags:# autoplay:flags.0?true loop:flags.1?true video_id:long caption:RichText = PageBlock"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0xd9d71866

    def __init__(self, video_id, caption, autoplay=None, loop=None):
        """
        :param autoplay: Telegram type: «true».
        :param loop: Telegram type: «true».
        :param video_id: Telegram type: «long».
        :param caption: Telegram type: «RichText».

        Constructor for PageBlock: Instance of either PageBlockUnsupported, PageBlockTitle, PageBlockSubtitle, PageBlockAuthorDate, PageBlockHeader, PageBlockSubheader, PageBlockParagraph, PageBlockPreformatted, PageBlockFooter, PageBlockDivider, PageBlockAnchor, PageBlockList, PageBlockBlockquote, PageBlockPullquote, PageBlockPhoto, PageBlockVideo, PageBlockCover, PageBlockEmbed, PageBlockEmbedPost, PageBlockCollage, PageBlockSlideshow, PageBlockChannel.
        """
        super().__init__()

        self.autoplay = autoplay
        self.loop = loop
        self.video_id = video_id
        self.caption = caption

    def on_send(self, writer):
        writer.write_int(PageBlockVideo.constructor_id, signed=False)
        # Calculate the flags. This equals to those flag arguments which are NOT None
        flags = 0
        flags |= (1 << 0) if self.autoplay else 0
        flags |= (1 << 1) if self.loop else 0
        writer.write_int(flags)

        writer.write_long(self.video_id)
        self.caption.on_send(writer)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return PageBlockVideo(None, None, None, None)

    def on_response(self, reader):
        flags = reader.read_int()

        if (flags & (1 << 0)) != 0:
            self.autoplay = True  # Arbitrary not-None value, no need to read since it is a flag

        if (flags & (1 << 1)) != 0:
            self.loop = True  # Arbitrary not-None value, no need to read since it is a flag

        self.video_id = reader.read_long()
        self.caption = reader.tgread_object()

    def __repr__(self):
        return 'pageBlockVideo#d9d71866 flags:# autoplay:flags.0?true loop:flags.1?true video_id:long caption:RichText = PageBlock'

    def __str__(self):
        return '(pageBlockVideo (ID: 0xd9d71866) = (autoplay={}, loop={}, video_id={}, caption={}))'.format(str(self.autoplay), str(self.loop), str(self.video_id), str(self.caption))



from ...tl.mtproto_request import MTProtoRequest


class UpdateChannelMessageViews(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    updateChannelMessageViews#98a12b4b channel_id:int id:int views:int = Update"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x98a12b4b

    def __init__(self, channel_id, id, views):
        """
        :param channel_id: Telegram type: «int».
        :param id: Telegram type: «int».
        :param views: Telegram type: «int».

        Constructor for Update: Instance of either UpdateNewMessage, UpdateMessageID, UpdateDeleteMessages, UpdateUserTyping, UpdateChatUserTyping, UpdateChatParticipants, UpdateUserStatus, UpdateUserName, UpdateUserPhoto, UpdateContactRegistered, UpdateContactLink, UpdateNewEncryptedMessage, UpdateEncryptedChatTyping, UpdateEncryption, UpdateEncryptedMessagesRead, UpdateChatParticipantAdd, UpdateChatParticipantDelete, UpdateDcOptions, UpdateUserBlocked, UpdateNotifySettings, UpdateServiceNotification, UpdatePrivacy, UpdateUserPhone, UpdateReadHistoryInbox, UpdateReadHistoryOutbox, UpdateWebPage, UpdateReadMessagesContents, UpdateChannelTooLong, UpdateChannel, UpdateNewChannelMessage, UpdateReadChannelInbox, UpdateDeleteChannelMessages, UpdateChannelMessageViews, UpdateChatAdmins, UpdateChatParticipantAdmin, UpdateNewStickerSet, UpdateStickerSetsOrder, UpdateStickerSets, UpdateSavedGifs, UpdateBotInlineQuery, UpdateBotInlineSend, UpdateEditChannelMessage, UpdateChannelPinnedMessage, UpdateBotCallbackQuery, UpdateEditMessage, UpdateInlineBotCallbackQuery, UpdateReadChannelOutbox, UpdateDraftMessage, UpdateReadFeaturedStickers, UpdateRecentStickers, UpdateConfig, UpdatePtsChanged, UpdateChannelWebPage, UpdateDialogPinned, UpdatePinnedDialogs, UpdateBotWebhookJSON, UpdateBotWebhookJSONQuery, UpdateBotShippingQuery, UpdateBotPrecheckoutQuery, UpdatePhoneCall.
        """
        super().__init__()

        self.channel_id = channel_id
        self.id = id
        self.views = views

    def on_send(self, writer):
        writer.write_int(UpdateChannelMessageViews.constructor_id, signed=False)
        writer.write_int(self.channel_id)
        writer.write_int(self.id)
        writer.write_int(self.views)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return UpdateChannelMessageViews(None, None, None)

    def on_response(self, reader):
        self.channel_id = reader.read_int()
        self.id = reader.read_int()
        self.views = reader.read_int()

    def __repr__(self):
        return 'updateChannelMessageViews#98a12b4b channel_id:int id:int views:int = Update'

    def __str__(self):
        return '(updateChannelMessageViews (ID: 0x98a12b4b) = (channel_id={}, id={}, views={}))'.format(str(self.channel_id), str(self.id), str(self.views))



from ...tl.mtproto_request import MTProtoRequest


class MessageService(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    messageService#9e19a1f6 flags:# out:flags.1?true mentioned:flags.4?true media_unread:flags.5?true silent:flags.13?true post:flags.14?true id:int from_id:flags.8?int to_id:Peer reply_to_msg_id:flags.3?int date:date action:MessageAction = Message"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x9e19a1f6

    def __init__(self, id, to_id, date, action, out=None, mentioned=None, media_unread=None, silent=None, post=None, from_id=None, reply_to_msg_id=None):
        """
        :param out: Telegram type: «true».
        :param mentioned: Telegram type: «true».
        :param media_unread: Telegram type: «true».
        :param silent: Telegram type: «true».
        :param post: Telegram type: «true».
        :param id: Telegram type: «int».
        :param from_id: Telegram type: «int».
        :param to_id: Telegram type: «Peer».
        :param reply_to_msg_id: Telegram type: «int».
        :param date: Telegram type: «date».
        :param action: Telegram type: «MessageAction».

        Constructor for Message: Instance of either MessageEmpty, Message, MessageService.
        """
        super().__init__()

        self.out = out
        self.mentioned = mentioned
        self.media_unread = media_unread
        self.silent = silent
        self.post = post
        self.id = id
        self.from_id = from_id
        self.to_id = to_id
        self.reply_to_msg_id = reply_to_msg_id
        self.date = date
        self.action = action

    def on_send(self, writer):
        writer.write_int(MessageService.constructor_id, signed=False)
        # Calculate the flags. This equals to those flag arguments which are NOT None
        flags = 0
        flags |= (1 << 1) if self.out else 0
        flags |= (1 << 4) if self.mentioned else 0
        flags |= (1 << 5) if self.media_unread else 0
        flags |= (1 << 13) if self.silent else 0
        flags |= (1 << 14) if self.post else 0
        flags |= (1 << 8) if self.from_id else 0
        flags |= (1 << 3) if self.reply_to_msg_id else 0
        writer.write_int(flags)

        writer.write_int(self.id)
        if self.from_id:
            writer.write_int(self.from_id)

        self.to_id.on_send(writer)
        if self.reply_to_msg_id:
            writer.write_int(self.reply_to_msg_id)

        writer.tgwrite_date(self.date)
        self.action.on_send(writer)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return MessageService(None, None, None, None, None, None, None, None, None, None, None)

    def on_response(self, reader):
        flags = reader.read_int()

        if (flags & (1 << 1)) != 0:
            self.out = True  # Arbitrary not-None value, no need to read since it is a flag

        if (flags & (1 << 4)) != 0:
            self.mentioned = True  # Arbitrary not-None value, no need to read since it is a flag

        if (flags & (1 << 5)) != 0:
            self.media_unread = True  # Arbitrary not-None value, no need to read since it is a flag

        if (flags & (1 << 13)) != 0:
            self.silent = True  # Arbitrary not-None value, no need to read since it is a flag

        if (flags & (1 << 14)) != 0:
            self.post = True  # Arbitrary not-None value, no need to read since it is a flag

        self.id = reader.read_int()
        if (flags & (1 << 8)) != 0:
            self.from_id = reader.read_int()

        self.to_id = reader.tgread_object()
        if (flags & (1 << 3)) != 0:
            self.reply_to_msg_id = reader.read_int()

        self.date = reader.tgread_date()
        self.action = reader.tgread_object()

    def __repr__(self):
        return 'messageService#9e19a1f6 flags:# out:flags.1?true mentioned:flags.4?true media_unread:flags.5?true silent:flags.13?true post:flags.14?true id:int from_id:flags.8?int to_id:Peer reply_to_msg_id:flags.3?int date:date action:MessageAction = Message'

    def __str__(self):
        return '(messageService (ID: 0x9e19a1f6) = (out={}, mentioned={}, media_unread={}, silent={}, post={}, id={}, from_id={}, to_id={}, reply_to_msg_id={}, date={}, action={}))'.format(str(self.out), str(self.mentioned), str(self.media_unread), str(self.silent), str(self.post), str(self.id), str(self.from_id), str(self.to_id), str(self.reply_to_msg_id), str(self.date), str(self.action))



from ...tl.mtproto_request import MTProtoRequest


class User(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    user#2e13f4c3 flags:# is_self:flags.10?true contact:flags.11?true mutual_contact:flags.12?true deleted:flags.13?true bot:flags.14?true bot_chat_history:flags.15?true bot_nochats:flags.16?true verified:flags.17?true restricted:flags.18?true min:flags.20?true bot_inline_geo:flags.21?true id:int access_hash:flags.0?long first_name:flags.1?string last_name:flags.2?string username:flags.3?string phone:flags.4?string photo:flags.5?UserProfilePhoto status:flags.6?UserStatus bot_info_version:flags.14?int restriction_reason:flags.18?string bot_inline_placeholder:flags.19?string lang_code:flags.22?string = User"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x2e13f4c3

    def __init__(self, id, is_self=None, contact=None, mutual_contact=None, deleted=None, bot=None, bot_chat_history=None, bot_nochats=None, verified=None, restricted=None, min=None, bot_inline_geo=None, access_hash=None, first_name=None, last_name=None, username=None, phone=None, photo=None, status=None, bot_info_version=None, restriction_reason=None, bot_inline_placeholder=None, lang_code=None):
        """
        :param is_self: Telegram type: «true».
        :param contact: Telegram type: «true».
        :param mutual_contact: Telegram type: «true».
        :param deleted: Telegram type: «true».
        :param bot: Telegram type: «true».
        :param bot_chat_history: Telegram type: «true».
        :param bot_nochats: Telegram type: «true».
        :param verified: Telegram type: «true».
        :param restricted: Telegram type: «true».
        :param min: Telegram type: «true».
        :param bot_inline_geo: Telegram type: «true».
        :param id: Telegram type: «int».
        :param access_hash: Telegram type: «long».
        :param first_name: Telegram type: «string».
        :param last_name: Telegram type: «string».
        :param username: Telegram type: «string».
        :param phone: Telegram type: «string».
        :param photo: Telegram type: «UserProfilePhoto».
        :param status: Telegram type: «UserStatus».
        :param bot_info_version: Telegram type: «int».
        :param restriction_reason: Telegram type: «string».
        :param bot_inline_placeholder: Telegram type: «string».
        :param lang_code: Telegram type: «string».

        Constructor for User: Instance of either UserEmpty, User.
        """
        super().__init__()

        self.is_self = is_self
        self.contact = contact
        self.mutual_contact = mutual_contact
        self.deleted = deleted
        self.bot = bot
        self.bot_chat_history = bot_chat_history
        self.bot_nochats = bot_nochats
        self.verified = verified
        self.restricted = restricted
        self.min = min
        self.bot_inline_geo = bot_inline_geo
        self.id = id
        self.access_hash = access_hash
        self.first_name = first_name
        self.last_name = last_name
        self.username = username
        self.phone = phone
        self.photo = photo
        self.status = status
        self.bot_info_version = bot_info_version
        self.restriction_reason = restriction_reason
        self.bot_inline_placeholder = bot_inline_placeholder
        self.lang_code = lang_code

    def on_send(self, writer):
        writer.write_int(User.constructor_id, signed=False)
        # Calculate the flags. This equals to those flag arguments which are NOT None
        flags = 0
        flags |= (1 << 10) if self.is_self else 0
        flags |= (1 << 11) if self.contact else 0
        flags |= (1 << 12) if self.mutual_contact else 0
        flags |= (1 << 13) if self.deleted else 0
        flags |= (1 << 14) if self.bot else 0
        flags |= (1 << 15) if self.bot_chat_history else 0
        flags |= (1 << 16) if self.bot_nochats else 0
        flags |= (1 << 17) if self.verified else 0
        flags |= (1 << 18) if self.restricted else 0
        flags |= (1 << 20) if self.min else 0
        flags |= (1 << 21) if self.bot_inline_geo else 0
        flags |= (1 << 0) if self.access_hash else 0
        flags |= (1 << 1) if self.first_name else 0
        flags |= (1 << 2) if self.last_name else 0
        flags |= (1 << 3) if self.username else 0
        flags |= (1 << 4) if self.phone else 0
        flags |= (1 << 5) if self.photo else 0
        flags |= (1 << 6) if self.status else 0
        flags |= (1 << 14) if self.bot_info_version else 0
        flags |= (1 << 18) if self.restriction_reason else 0
        flags |= (1 << 19) if self.bot_inline_placeholder else 0
        flags |= (1 << 22) if self.lang_code else 0
        writer.write_int(flags)

        writer.write_int(self.id)
        if self.access_hash:
            writer.write_long(self.access_hash)

        if self.first_name:
            writer.tgwrite_string(self.first_name)

        if self.last_name:
            writer.tgwrite_string(self.last_name)

        if self.username:
            writer.tgwrite_string(self.username)

        if self.phone:
            writer.tgwrite_string(self.phone)

        if self.photo:
            self.photo.on_send(writer)

        if self.status:
            self.status.on_send(writer)

        if self.bot_info_version:
            writer.write_int(self.bot_info_version)

        if self.restriction_reason:
            writer.tgwrite_string(self.restriction_reason)

        if self.bot_inline_placeholder:
            writer.tgwrite_string(self.bot_inline_placeholder)

        if self.lang_code:
            writer.tgwrite_string(self.lang_code)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return User(None, None, None, None, None, None, None, None, None, None, None, None, None, None, None, None, None, None, None, None, None, None, None)

    def on_response(self, reader):
        flags = reader.read_int()

        if (flags & (1 << 10)) != 0:
            self.is_self = True  # Arbitrary not-None value, no need to read since it is a flag

        if (flags & (1 << 11)) != 0:
            self.contact = True  # Arbitrary not-None value, no need to read since it is a flag

        if (flags & (1 << 12)) != 0:
            self.mutual_contact = True  # Arbitrary not-None value, no need to read since it is a flag

        if (flags & (1 << 13)) != 0:
            self.deleted = True  # Arbitrary not-None value, no need to read since it is a flag

        if (flags & (1 << 14)) != 0:
            self.bot = True  # Arbitrary not-None value, no need to read since it is a flag

        if (flags & (1 << 15)) != 0:
            self.bot_chat_history = True  # Arbitrary not-None value, no need to read since it is a flag

        if (flags & (1 << 16)) != 0:
            self.bot_nochats = True  # Arbitrary not-None value, no need to read since it is a flag

        if (flags & (1 << 17)) != 0:
            self.verified = True  # Arbitrary not-None value, no need to read since it is a flag

        if (flags & (1 << 18)) != 0:
            self.restricted = True  # Arbitrary not-None value, no need to read since it is a flag

        if (flags & (1 << 20)) != 0:
            self.min = True  # Arbitrary not-None value, no need to read since it is a flag

        if (flags & (1 << 21)) != 0:
            self.bot_inline_geo = True  # Arbitrary not-None value, no need to read since it is a flag

        self.id = reader.read_int()
        if (flags & (1 << 0)) != 0:
            self.access_hash = reader.read_long()

        if (flags & (1 << 1)) != 0:
            self.first_name = reader.tgread_string()

        if (flags & (1 << 2)) != 0:
            self.last_name = reader.tgread_string()

        if (flags & (1 << 3)) != 0:
            self.username = reader.tgread_string()

        if (flags & (1 << 4)) != 0:
            self.phone = reader.tgread_string()

        if (flags & (1 << 5)) != 0:
            self.photo = reader.tgread_object()

        if (flags & (1 << 6)) != 0:
            self.status = reader.tgread_object()

        if (flags & (1 << 14)) != 0:
            self.bot_info_version = reader.read_int()

        if (flags & (1 << 18)) != 0:
            self.restriction_reason = reader.tgread_string()

        if (flags & (1 << 19)) != 0:
            self.bot_inline_placeholder = reader.tgread_string()

        if (flags & (1 << 22)) != 0:
            self.lang_code = reader.tgread_string()

    def __repr__(self):
        return 'user#2e13f4c3 flags:# is_self:flags.10?true contact:flags.11?true mutual_contact:flags.12?true deleted:flags.13?true bot:flags.14?true bot_chat_history:flags.15?true bot_nochats:flags.16?true verified:flags.17?true restricted:flags.18?true min:flags.20?true bot_inline_geo:flags.21?true id:int access_hash:flags.0?long first_name:flags.1?string last_name:flags.2?string username:flags.3?string phone:flags.4?string photo:flags.5?UserProfilePhoto status:flags.6?UserStatus bot_info_version:flags.14?int restriction_reason:flags.18?string bot_inline_placeholder:flags.19?string lang_code:flags.22?string = User'

    def __str__(self):
        return '(user (ID: 0x2e13f4c3) = (is_self={}, contact={}, mutual_contact={}, deleted={}, bot={}, bot_chat_history={}, bot_nochats={}, verified={}, restricted={}, min={}, bot_inline_geo={}, id={}, access_hash={}, first_name={}, last_name={}, username={}, phone={}, photo={}, status={}, bot_info_version={}, restriction_reason={}, bot_inline_placeholder={}, lang_code={}))'.format(str(self.is_self), str(self.contact), str(self.mutual_contact), str(self.deleted), str(self.bot), str(self.bot_chat_history), str(self.bot_nochats), str(self.verified), str(self.restricted), str(self.min), str(self.bot_inline_geo), str(self.id), str(self.access_hash), str(self.first_name), str(self.last_name), str(self.username), str(self.phone), str(self.photo), str(self.status), str(self.bot_info_version), str(self.restriction_reason), str(self.bot_inline_placeholder), str(self.lang_code))



from ...tl.mtproto_request import MTProtoRequest


class PaymentRequestedInfo(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    paymentRequestedInfo#909c3f94 flags:# name:flags.0?string phone:flags.1?string email:flags.2?string shipping_address:flags.3?PostAddress = PaymentRequestedInfo"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x909c3f94

    def __init__(self, name=None, phone=None, email=None, shipping_address=None):
        """
        :param name: Telegram type: «string».
        :param phone: Telegram type: «string».
        :param email: Telegram type: «string».
        :param shipping_address: Telegram type: «PostAddress».

        Constructor for PaymentRequestedInfo: Instance of PaymentRequestedInfo.
        """
        super().__init__()

        self.name = name
        self.phone = phone
        self.email = email
        self.shipping_address = shipping_address

    def on_send(self, writer):
        writer.write_int(PaymentRequestedInfo.constructor_id, signed=False)
        # Calculate the flags. This equals to those flag arguments which are NOT None
        flags = 0
        flags |= (1 << 0) if self.name else 0
        flags |= (1 << 1) if self.phone else 0
        flags |= (1 << 2) if self.email else 0
        flags |= (1 << 3) if self.shipping_address else 0
        writer.write_int(flags)

        if self.name:
            writer.tgwrite_string(self.name)

        if self.phone:
            writer.tgwrite_string(self.phone)

        if self.email:
            writer.tgwrite_string(self.email)

        if self.shipping_address:
            self.shipping_address.on_send(writer)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return PaymentRequestedInfo(None, None, None, None)

    def on_response(self, reader):
        flags = reader.read_int()

        if (flags & (1 << 0)) != 0:
            self.name = reader.tgread_string()

        if (flags & (1 << 1)) != 0:
            self.phone = reader.tgread_string()

        if (flags & (1 << 2)) != 0:
            self.email = reader.tgread_string()

        if (flags & (1 << 3)) != 0:
            self.shipping_address = reader.tgread_object()

    def __repr__(self):
        return 'paymentRequestedInfo#909c3f94 flags:# name:flags.0?string phone:flags.1?string email:flags.2?string shipping_address:flags.3?PostAddress = PaymentRequestedInfo'

    def __str__(self):
        return '(paymentRequestedInfo (ID: 0x909c3f94) = (name={}, phone={}, email={}, shipping_address={}))'.format(str(self.name), str(self.phone), str(self.email), str(self.shipping_address))



from ...tl.mtproto_request import MTProtoRequest


class MsgDetailedInfo(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    msg_detailed_info#276d3ec6 msg_id:long answer_msg_id:long bytes:int status:int = MsgDetailedInfo"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x276d3ec6

    def __init__(self, msg_id, answer_msg_id, bytes, status):
        """
        :param msg_id: Telegram type: «long».
        :param answer_msg_id: Telegram type: «long».
        :param bytes: Telegram type: «int».
        :param status: Telegram type: «int».

        Constructor for MsgDetailedInfo: Instance of either MsgDetailedInfo, MsgNewDetailedInfo.
        """
        super().__init__()

        self.msg_id = msg_id
        self.answer_msg_id = answer_msg_id
        self.bytes = bytes
        self.status = status

    def on_send(self, writer):
        writer.write_int(MsgDetailedInfo.constructor_id, signed=False)
        writer.write_long(self.msg_id)
        writer.write_long(self.answer_msg_id)
        writer.write_int(self.bytes)
        writer.write_int(self.status)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return MsgDetailedInfo(None, None, None, None)

    def on_response(self, reader):
        self.msg_id = reader.read_long()
        self.answer_msg_id = reader.read_long()
        self.bytes = reader.read_int()
        self.status = reader.read_int()

    def __repr__(self):
        return 'msg_detailed_info#276d3ec6 msg_id:long answer_msg_id:long bytes:int status:int = MsgDetailedInfo'

    def __str__(self):
        return '(msg_detailed_info (ID: 0x276d3ec6) = (msg_id={}, answer_msg_id={}, bytes={}, status={}))'.format(str(self.msg_id), str(self.answer_msg_id), str(self.bytes), str(self.status))



from .dialogs import Dialogs
from .dialogs_slice import DialogsSlice
from .messages import Messages
from .messages_slice import MessagesSlice
from .channel_messages import ChannelMessages
from .chats import Chats
from .chats_slice import ChatsSlice
from .chat_full import ChatFull
from .affected_history import AffectedHistory
from .dh_config_not_modified import DhConfigNotModified
from .dh_config import DhConfig
from .sent_encrypted_message import SentEncryptedMessage
from .sent_encrypted_file import SentEncryptedFile
from .stickers_not_modified import StickersNotModified
from .stickers import Stickers
from .all_stickers_not_modified import AllStickersNotModified
from .all_stickers import AllStickers
from .affected_messages import AffectedMessages
from .sticker_set import StickerSet
from .found_gifs import FoundGifs
from .saved_gifs_not_modified import SavedGifsNotModified
from .saved_gifs import SavedGifs
from .bot_results import BotResults
from .bot_callback_answer import BotCallbackAnswer
from .message_edit_data import MessageEditData
from .peer_dialogs import PeerDialogs
from .featured_stickers_not_modified import FeaturedStickersNotModified
from .featured_stickers import FeaturedStickers
from .recent_stickers_not_modified import RecentStickersNotModified
from .recent_stickers import RecentStickers
from .archived_stickers import ArchivedStickers
from .sticker_set_install_result_success import StickerSetInstallResultSuccess
from .sticker_set_install_result_archive import StickerSetInstallResultArchive
from .high_scores import HighScores



from ....tl.mtproto_request import MTProtoRequest


class SendPaymentFormRequest(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    payments.sendPaymentForm#2b8879b3 flags:# msg_id:int requested_info_id:flags.0?string shipping_option_id:flags.1?string credentials:InputPaymentCredentials = payments.PaymentResult"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x2b8879b3

    def __init__(self, msg_id, credentials, requested_info_id=None, shipping_option_id=None):
        """
        :param msg_id: Telegram type: «int».
        :param requested_info_id: Telegram type: «string».
        :param shipping_option_id: Telegram type: «string».
        :param credentials: Telegram type: «InputPaymentCredentials».

        :returns payments.PaymentResult: Instance of either PaymentResult, PaymentVerficationNeeded.
        """
        super().__init__()
        self.result = None
        self.confirmed = True  # Confirmed by default

        self.msg_id = msg_id
        self.requested_info_id = requested_info_id
        self.shipping_option_id = shipping_option_id
        self.credentials = credentials

    def on_send(self, writer):
        writer.write_int(SendPaymentFormRequest.constructor_id, signed=False)
        # Calculate the flags. This equals to those flag arguments which are NOT None
        flags = 0
        flags |= (1 << 0) if self.requested_info_id else 0
        flags |= (1 << 1) if self.shipping_option_id else 0
        writer.write_int(flags)

        writer.write_int(self.msg_id)
        if self.requested_info_id:
            writer.tgwrite_string(self.requested_info_id)

        if self.shipping_option_id:
            writer.tgwrite_string(self.shipping_option_id)

        self.credentials.on_send(writer)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return SendPaymentFormRequest(None, None, None, None)

    def on_response(self, reader):
        self.result = reader.tgread_object()

    def __repr__(self):
        return 'payments.sendPaymentForm#2b8879b3 flags:# msg_id:int requested_info_id:flags.0?string shipping_option_id:flags.1?string credentials:InputPaymentCredentials = payments.PaymentResult'

    def __str__(self):
        return '(payments.sendPaymentForm (ID: 0x2b8879b3) = (msg_id={}, requested_info_id={}, shipping_option_id={}, credentials={}))'.format(str(self.msg_id), str(self.requested_info_id), str(self.shipping_option_id), str(self.credentials))



from ...tl.mtproto_request import MTProtoRequest


class UpdateBotWebhookJSONQuery(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    updateBotWebhookJSONQuery#9b9240a6 query_id:long data:DataJSON timeout:int = Update"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x9b9240a6

    def __init__(self, query_id, data, timeout):
        """
        :param query_id: Telegram type: «long».
        :param data: Telegram type: «DataJSON».
        :param timeout: Telegram type: «int».

        Constructor for Update: Instance of either UpdateNewMessage, UpdateMessageID, UpdateDeleteMessages, UpdateUserTyping, UpdateChatUserTyping, UpdateChatParticipants, UpdateUserStatus, UpdateUserName, UpdateUserPhoto, UpdateContactRegistered, UpdateContactLink, UpdateNewEncryptedMessage, UpdateEncryptedChatTyping, UpdateEncryption, UpdateEncryptedMessagesRead, UpdateChatParticipantAdd, UpdateChatParticipantDelete, UpdateDcOptions, UpdateUserBlocked, UpdateNotifySettings, UpdateServiceNotification, UpdatePrivacy, UpdateUserPhone, UpdateReadHistoryInbox, UpdateReadHistoryOutbox, UpdateWebPage, UpdateReadMessagesContents, UpdateChannelTooLong, UpdateChannel, UpdateNewChannelMessage, UpdateReadChannelInbox, UpdateDeleteChannelMessages, UpdateChannelMessageViews, UpdateChatAdmins, UpdateChatParticipantAdmin, UpdateNewStickerSet, UpdateStickerSetsOrder, UpdateStickerSets, UpdateSavedGifs, UpdateBotInlineQuery, UpdateBotInlineSend, UpdateEditChannelMessage, UpdateChannelPinnedMessage, UpdateBotCallbackQuery, UpdateEditMessage, UpdateInlineBotCallbackQuery, UpdateReadChannelOutbox, UpdateDraftMessage, UpdateReadFeaturedStickers, UpdateRecentStickers, UpdateConfig, UpdatePtsChanged, UpdateChannelWebPage, UpdateDialogPinned, UpdatePinnedDialogs, UpdateBotWebhookJSON, UpdateBotWebhookJSONQuery, UpdateBotShippingQuery, UpdateBotPrecheckoutQuery, UpdatePhoneCall.
        """
        super().__init__()

        self.query_id = query_id
        self.data = data
        self.timeout = timeout

    def on_send(self, writer):
        writer.write_int(UpdateBotWebhookJSONQuery.constructor_id, signed=False)
        writer.write_long(self.query_id)
        self.data.on_send(writer)
        writer.write_int(self.timeout)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return UpdateBotWebhookJSONQuery(None, None, None)

    def on_response(self, reader):
        self.query_id = reader.read_long()
        self.data = reader.tgread_object()
        self.timeout = reader.read_int()

    def __repr__(self):
        return 'updateBotWebhookJSONQuery#9b9240a6 query_id:long data:DataJSON timeout:int = Update'

    def __str__(self):
        return '(updateBotWebhookJSONQuery (ID: 0x9b9240a6) = (query_id={}, data={}, timeout={}))'.format(str(self.query_id), str(self.data), str(self.timeout))



from ...tl.mtproto_request import MTProtoRequest


class PageBlockEmbedPost(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    pageBlockEmbedPost#292c7be9 url:string webpage_id:long author_photo_id:long author:string date:date blocks:Vector<PageBlock> caption:RichText = PageBlock"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x292c7be9

    def __init__(self, url, webpage_id, author_photo_id, author, date, blocks, caption):
        """
        :param url: Telegram type: «string».
        :param webpage_id: Telegram type: «long».
        :param author_photo_id: Telegram type: «long».
        :param author: Telegram type: «string».
        :param date: Telegram type: «date».
        :param blocks: Telegram type: «PageBlock». Must be a list.
        :param caption: Telegram type: «RichText».

        Constructor for PageBlock: Instance of either PageBlockUnsupported, PageBlockTitle, PageBlockSubtitle, PageBlockAuthorDate, PageBlockHeader, PageBlockSubheader, PageBlockParagraph, PageBlockPreformatted, PageBlockFooter, PageBlockDivider, PageBlockAnchor, PageBlockList, PageBlockBlockquote, PageBlockPullquote, PageBlockPhoto, PageBlockVideo, PageBlockCover, PageBlockEmbed, PageBlockEmbedPost, PageBlockCollage, PageBlockSlideshow, PageBlockChannel.
        """
        super().__init__()

        self.url = url
        self.webpage_id = webpage_id
        self.author_photo_id = author_photo_id
        self.author = author
        self.date = date
        self.blocks = blocks
        self.caption = caption

    def on_send(self, writer):
        writer.write_int(PageBlockEmbedPost.constructor_id, signed=False)
        writer.tgwrite_string(self.url)
        writer.write_long(self.webpage_id)
        writer.write_long(self.author_photo_id)
        writer.tgwrite_string(self.author)
        writer.tgwrite_date(self.date)
        writer.write_int(0x1cb5c415, signed=False)  # Vector's constructor ID
        writer.write_int(len(self.blocks))
        for blocks_item in self.blocks:
            blocks_item.on_send(writer)

        self.caption.on_send(writer)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return PageBlockEmbedPost(None, None, None, None, None, None, None)

    def on_response(self, reader):
        self.url = reader.tgread_string()
        self.webpage_id = reader.read_long()
        self.author_photo_id = reader.read_long()
        self.author = reader.tgread_string()
        self.date = reader.tgread_date()
        reader.read_int()  # Vector's constructor ID
        self.blocks = []  # Initialize an empty list
        blocks_len = reader.read_int()
        for _ in range(blocks_len):
            blocks_item = reader.tgread_object()
            self.blocks.append(blocks_item)

        self.caption = reader.tgread_object()

    def __repr__(self):
        return 'pageBlockEmbedPost#292c7be9 url:string webpage_id:long author_photo_id:long author:string date:date blocks:Vector<PageBlock> caption:RichText = PageBlock'

    def __str__(self):
        return '(pageBlockEmbedPost (ID: 0x292c7be9) = (url={}, webpage_id={}, author_photo_id={}, author={}, date={}, blocks={}, caption={}))'.format(str(self.url), str(self.webpage_id), str(self.author_photo_id), str(self.author), str(self.date), None if not self.blocks else [str(_) for _ in self.blocks], str(self.caption))



from ....tl.mtproto_request import MTProtoRequest


class InstallStickerSetRequest(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    messages.installStickerSet#c78fe460 stickerset:InputStickerSet archived:Bool = messages.StickerSetInstallResult"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0xc78fe460

    def __init__(self, stickerset, archived):
        """
        :param stickerset: Telegram type: «InputStickerSet».
        :param archived: Telegram type: «Bool».

        :returns messages.StickerSetInstallResult: Instance of either StickerSetInstallResultSuccess, StickerSetInstallResultArchive.
        """
        super().__init__()
        self.result = None
        self.confirmed = True  # Confirmed by default

        self.stickerset = stickerset
        self.archived = archived

    def on_send(self, writer):
        writer.write_int(InstallStickerSetRequest.constructor_id, signed=False)
        self.stickerset.on_send(writer)
        writer.tgwrite_bool(self.archived)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return InstallStickerSetRequest(None, None)

    def on_response(self, reader):
        self.result = reader.tgread_object()

    def __repr__(self):
        return 'messages.installStickerSet#c78fe460 stickerset:InputStickerSet archived:Bool = messages.StickerSetInstallResult'

    def __str__(self):
        return '(messages.installStickerSet (ID: 0xc78fe460) = (stickerset={}, archived={}))'.format(str(self.stickerset), str(self.archived))



from ...tl.mtproto_request import MTProtoRequest


class FutureSalts(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    future_salts#ae500895 req_msg_id:long now:int salts:vector<future_salt> = FutureSalts"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0xae500895

    def __init__(self, req_msg_id, now, salts):
        """
        :param req_msg_id: Telegram type: «long».
        :param now: Telegram type: «int».
        :param salts: Telegram type: «future_salt». Must be a list.

        Constructor for FutureSalts: Instance of FutureSalts.
        """
        super().__init__()

        self.req_msg_id = req_msg_id
        self.now = now
        self.salts = salts

    def on_send(self, writer):
        writer.write_int(FutureSalts.constructor_id, signed=False)
        writer.write_long(self.req_msg_id)
        writer.write_int(self.now)
        writer.write_int(len(self.salts))
        for salts_item in self.salts:
            salts_item.on_send(writer)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return FutureSalts(None, None, None)

    def on_response(self, reader):
        self.req_msg_id = reader.read_long()
        self.now = reader.read_int()
        self.salts = []  # Initialize an empty list
        salts_len = reader.read_int()
        for _ in range(salts_len):
            salts_item = reader.tgread_object()
            self.salts.append(salts_item)

    def __repr__(self):
        return 'future_salts#ae500895 req_msg_id:long now:int salts:vector<future_salt> = FutureSalts'

    def __str__(self):
        return '(future_salts (ID: 0xae500895) = (req_msg_id={}, now={}, salts={}))'.format(str(self.req_msg_id), str(self.now), None if not self.salts else [str(_) for _ in self.salts])



from ...tl.mtproto_request import MTProtoRequest


class UpdateUserPhone(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    updateUserPhone#12b9417b user_id:int phone:string = Update"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x12b9417b

    def __init__(self, user_id, phone):
        """
        :param user_id: Telegram type: «int».
        :param phone: Telegram type: «string».

        Constructor for Update: Instance of either UpdateNewMessage, UpdateMessageID, UpdateDeleteMessages, UpdateUserTyping, UpdateChatUserTyping, UpdateChatParticipants, UpdateUserStatus, UpdateUserName, UpdateUserPhoto, UpdateContactRegistered, UpdateContactLink, UpdateNewEncryptedMessage, UpdateEncryptedChatTyping, UpdateEncryption, UpdateEncryptedMessagesRead, UpdateChatParticipantAdd, UpdateChatParticipantDelete, UpdateDcOptions, UpdateUserBlocked, UpdateNotifySettings, UpdateServiceNotification, UpdatePrivacy, UpdateUserPhone, UpdateReadHistoryInbox, UpdateReadHistoryOutbox, UpdateWebPage, UpdateReadMessagesContents, UpdateChannelTooLong, UpdateChannel, UpdateNewChannelMessage, UpdateReadChannelInbox, UpdateDeleteChannelMessages, UpdateChannelMessageViews, UpdateChatAdmins, UpdateChatParticipantAdmin, UpdateNewStickerSet, UpdateStickerSetsOrder, UpdateStickerSets, UpdateSavedGifs, UpdateBotInlineQuery, UpdateBotInlineSend, UpdateEditChannelMessage, UpdateChannelPinnedMessage, UpdateBotCallbackQuery, UpdateEditMessage, UpdateInlineBotCallbackQuery, UpdateReadChannelOutbox, UpdateDraftMessage, UpdateReadFeaturedStickers, UpdateRecentStickers, UpdateConfig, UpdatePtsChanged, UpdateChannelWebPage, UpdateDialogPinned, UpdatePinnedDialogs, UpdateBotWebhookJSON, UpdateBotWebhookJSONQuery, UpdateBotShippingQuery, UpdateBotPrecheckoutQuery, UpdatePhoneCall.
        """
        super().__init__()

        self.user_id = user_id
        self.phone = phone

    def on_send(self, writer):
        writer.write_int(UpdateUserPhone.constructor_id, signed=False)
        writer.write_int(self.user_id)
        writer.tgwrite_string(self.phone)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return UpdateUserPhone(None, None)

    def on_response(self, reader):
        self.user_id = reader.read_int()
        self.phone = reader.tgread_string()

    def __repr__(self):
        return 'updateUserPhone#12b9417b user_id:int phone:string = Update'

    def __str__(self):
        return '(updateUserPhone (ID: 0x12b9417b) = (user_id={}, phone={}))'.format(str(self.user_id), str(self.phone))



from ...tl.mtproto_request import MTProtoRequest


class UserStatusOffline(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    userStatusOffline#008c703f was_online:date = UserStatus"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x8c703f

    def __init__(self, was_online):
        """
        :param was_online: Telegram type: «date».

        Constructor for UserStatus: Instance of either UserStatusEmpty, UserStatusOnline, UserStatusOffline, UserStatusRecently, UserStatusLastWeek, UserStatusLastMonth.
        """
        super().__init__()

        self.was_online = was_online

    def on_send(self, writer):
        writer.write_int(UserStatusOffline.constructor_id, signed=False)
        writer.tgwrite_date(self.was_online)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return UserStatusOffline(None)

    def on_response(self, reader):
        self.was_online = reader.tgread_date()

    def __repr__(self):
        return 'userStatusOffline#008c703f was_online:date = UserStatus'

    def __str__(self):
        return '(userStatusOffline (ID: 0x8c703f) = (was_online={}))'.format(str(self.was_online))



from ...tl.mtproto_request import MTProtoRequest


class InputGeoPoint(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    inputGeoPoint#f3b7acc9 lat:double long:double = InputGeoPoint"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0xf3b7acc9

    def __init__(self, lat, long):
        """
        :param lat: Telegram type: «double».
        :param long: Telegram type: «double».

        Constructor for InputGeoPoint: Instance of either InputGeoPointEmpty, InputGeoPoint.
        """
        super().__init__()

        self.lat = lat
        self.long = long

    def on_send(self, writer):
        writer.write_int(InputGeoPoint.constructor_id, signed=False)
        writer.write_double(self.lat)
        writer.write_double(self.long)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return InputGeoPoint(None, None)

    def on_response(self, reader):
        self.lat = reader.read_double()
        self.long = reader.read_double()

    def __repr__(self):
        return 'inputGeoPoint#f3b7acc9 lat:double long:double = InputGeoPoint'

    def __str__(self):
        return '(inputGeoPoint (ID: 0xf3b7acc9) = (lat={}, long={}))'.format(str(self.lat), str(self.long))



from ...tl.mtproto_request import MTProtoRequest


class PostAddress(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    postAddress#1e8caaeb street_line1:string street_line2:string city:string state:string country_iso2:string post_code:string = PostAddress"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x1e8caaeb

    def __init__(self, street_line1, street_line2, city, state, country_iso2, post_code):
        """
        :param street_line1: Telegram type: «string».
        :param street_line2: Telegram type: «string».
        :param city: Telegram type: «string».
        :param state: Telegram type: «string».
        :param country_iso2: Telegram type: «string».
        :param post_code: Telegram type: «string».

        Constructor for PostAddress: Instance of PostAddress.
        """
        super().__init__()

        self.street_line1 = street_line1
        self.street_line2 = street_line2
        self.city = city
        self.state = state
        self.country_iso2 = country_iso2
        self.post_code = post_code

    def on_send(self, writer):
        writer.write_int(PostAddress.constructor_id, signed=False)
        writer.tgwrite_string(self.street_line1)
        writer.tgwrite_string(self.street_line2)
        writer.tgwrite_string(self.city)
        writer.tgwrite_string(self.state)
        writer.tgwrite_string(self.country_iso2)
        writer.tgwrite_string(self.post_code)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return PostAddress(None, None, None, None, None, None)

    def on_response(self, reader):
        self.street_line1 = reader.tgread_string()
        self.street_line2 = reader.tgread_string()
        self.city = reader.tgread_string()
        self.state = reader.tgread_string()
        self.country_iso2 = reader.tgread_string()
        self.post_code = reader.tgread_string()

    def __repr__(self):
        return 'postAddress#1e8caaeb street_line1:string street_line2:string city:string state:string country_iso2:string post_code:string = PostAddress'

    def __str__(self):
        return '(postAddress (ID: 0x1e8caaeb) = (street_line1={}, street_line2={}, city={}, state={}, country_iso2={}, post_code={}))'.format(str(self.street_line1), str(self.street_line2), str(self.city), str(self.state), str(self.country_iso2), str(self.post_code))



from ...tl.mtproto_request import MTProtoRequest


class UpdateServiceNotification(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    updateServiceNotification#ebe46819 flags:# popup:flags.0?true inbox_date:flags.1?date type:string message:string media:MessageMedia entities:Vector<MessageEntity> = Update"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0xebe46819

    def __init__(self, type, message, media, entities, popup=None, inbox_date=None):
        """
        :param popup: Telegram type: «true».
        :param inbox_date: Telegram type: «date».
        :param type: Telegram type: «string».
        :param message: Telegram type: «string».
        :param media: Telegram type: «MessageMedia».
        :param entities: Telegram type: «MessageEntity». Must be a list.

        Constructor for Update: Instance of either UpdateNewMessage, UpdateMessageID, UpdateDeleteMessages, UpdateUserTyping, UpdateChatUserTyping, UpdateChatParticipants, UpdateUserStatus, UpdateUserName, UpdateUserPhoto, UpdateContactRegistered, UpdateContactLink, UpdateNewEncryptedMessage, UpdateEncryptedChatTyping, UpdateEncryption, UpdateEncryptedMessagesRead, UpdateChatParticipantAdd, UpdateChatParticipantDelete, UpdateDcOptions, UpdateUserBlocked, UpdateNotifySettings, UpdateServiceNotification, UpdatePrivacy, UpdateUserPhone, UpdateReadHistoryInbox, UpdateReadHistoryOutbox, UpdateWebPage, UpdateReadMessagesContents, UpdateChannelTooLong, UpdateChannel, UpdateNewChannelMessage, UpdateReadChannelInbox, UpdateDeleteChannelMessages, UpdateChannelMessageViews, UpdateChatAdmins, UpdateChatParticipantAdmin, UpdateNewStickerSet, UpdateStickerSetsOrder, UpdateStickerSets, UpdateSavedGifs, UpdateBotInlineQuery, UpdateBotInlineSend, UpdateEditChannelMessage, UpdateChannelPinnedMessage, UpdateBotCallbackQuery, UpdateEditMessage, UpdateInlineBotCallbackQuery, UpdateReadChannelOutbox, UpdateDraftMessage, UpdateReadFeaturedStickers, UpdateRecentStickers, UpdateConfig, UpdatePtsChanged, UpdateChannelWebPage, UpdateDialogPinned, UpdatePinnedDialogs, UpdateBotWebhookJSON, UpdateBotWebhookJSONQuery, UpdateBotShippingQuery, UpdateBotPrecheckoutQuery, UpdatePhoneCall.
        """
        super().__init__()

        self.popup = popup
        self.inbox_date = inbox_date
        self.type = type
        self.message = message
        self.media = media
        self.entities = entities

    def on_send(self, writer):
        writer.write_int(UpdateServiceNotification.constructor_id, signed=False)
        # Calculate the flags. This equals to those flag arguments which are NOT None
        flags = 0
        flags |= (1 << 0) if self.popup else 0
        flags |= (1 << 1) if self.inbox_date else 0
        writer.write_int(flags)

        if self.inbox_date:
            writer.tgwrite_date(self.inbox_date)

        writer.tgwrite_string(self.type)
        writer.tgwrite_string(self.message)
        self.media.on_send(writer)
        writer.write_int(0x1cb5c415, signed=False)  # Vector's constructor ID
        writer.write_int(len(self.entities))
        for entities_item in self.entities:
            entities_item.on_send(writer)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return UpdateServiceNotification(None, None, None, None, None, None)

    def on_response(self, reader):
        flags = reader.read_int()

        if (flags & (1 << 0)) != 0:
            self.popup = True  # Arbitrary not-None value, no need to read since it is a flag

        if (flags & (1 << 1)) != 0:
            self.inbox_date = reader.tgread_date()

        self.type = reader.tgread_string()
        self.message = reader.tgread_string()
        self.media = reader.tgread_object()
        reader.read_int()  # Vector's constructor ID
        self.entities = []  # Initialize an empty list
        entities_len = reader.read_int()
        for _ in range(entities_len):
            entities_item = reader.tgread_object()
            self.entities.append(entities_item)

    def __repr__(self):
        return 'updateServiceNotification#ebe46819 flags:# popup:flags.0?true inbox_date:flags.1?date type:string message:string media:MessageMedia entities:Vector<MessageEntity> = Update'

    def __str__(self):
        return '(updateServiceNotification (ID: 0xebe46819) = (popup={}, inbox_date={}, type={}, message={}, media={}, entities={}))'.format(str(self.popup), str(self.inbox_date), str(self.type), str(self.message), str(self.media), None if not self.entities else [str(_) for _ in self.entities])



from ...tl.mtproto_request import MTProtoRequest


class StickerSetCovered(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    stickerSetCovered#6410a5d2 set:StickerSet cover:Document = StickerSetCovered"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x6410a5d2

    def __init__(self, set, cover):
        """
        :param set: Telegram type: «StickerSet».
        :param cover: Telegram type: «Document».

        Constructor for StickerSetCovered: Instance of either StickerSetCovered, StickerSetMultiCovered.
        """
        super().__init__()

        self.set = set
        self.cover = cover

    def on_send(self, writer):
        writer.write_int(StickerSetCovered.constructor_id, signed=False)
        self.set.on_send(writer)
        self.cover.on_send(writer)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return StickerSetCovered(None, None)

    def on_response(self, reader):
        self.set = reader.tgread_object()
        self.cover = reader.tgread_object()

    def __repr__(self):
        return 'stickerSetCovered#6410a5d2 set:StickerSet cover:Document = StickerSetCovered'

    def __str__(self):
        return '(stickerSetCovered (ID: 0x6410a5d2) = (set={}, cover={}))'.format(str(self.set), str(self.cover))



from ...tl.mtproto_request import MTProtoRequest


class PhoneCall(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    phoneCall#ffe6ab67 id:long access_hash:long date:date admin_id:int participant_id:int g_a_or_b:bytes key_fingerprint:long protocol:PhoneCallProtocol connection:PhoneConnection alternative_connections:Vector<PhoneConnection> start_date:date = PhoneCall"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0xffe6ab67

    def __init__(self, id, access_hash, date, admin_id, participant_id, g_a_or_b, key_fingerprint, protocol, connection, alternative_connections, start_date):
        """
        :param id: Telegram type: «long».
        :param access_hash: Telegram type: «long».
        :param date: Telegram type: «date».
        :param admin_id: Telegram type: «int».
        :param participant_id: Telegram type: «int».
        :param g_a_or_b: Telegram type: «bytes».
        :param key_fingerprint: Telegram type: «long».
        :param protocol: Telegram type: «PhoneCallProtocol».
        :param connection: Telegram type: «PhoneConnection».
        :param alternative_connections: Telegram type: «PhoneConnection». Must be a list.
        :param start_date: Telegram type: «date».

        Constructor for PhoneCall: Instance of either PhoneCallEmpty, PhoneCallWaiting, PhoneCallRequested, PhoneCallAccepted, PhoneCall, PhoneCallDiscarded.
        """
        super().__init__()

        self.id = id
        self.access_hash = access_hash
        self.date = date
        self.admin_id = admin_id
        self.participant_id = participant_id
        self.g_a_or_b = g_a_or_b
        self.key_fingerprint = key_fingerprint
        self.protocol = protocol
        self.connection = connection
        self.alternative_connections = alternative_connections
        self.start_date = start_date

    def on_send(self, writer):
        writer.write_int(PhoneCall.constructor_id, signed=False)
        writer.write_long(self.id)
        writer.write_long(self.access_hash)
        writer.tgwrite_date(self.date)
        writer.write_int(self.admin_id)
        writer.write_int(self.participant_id)
        writer.tgwrite_bytes(self.g_a_or_b)
        writer.write_long(self.key_fingerprint)
        self.protocol.on_send(writer)
        self.connection.on_send(writer)
        writer.write_int(0x1cb5c415, signed=False)  # Vector's constructor ID
        writer.write_int(len(self.alternative_connections))
        for alternative_connections_item in self.alternative_connections:
            alternative_connections_item.on_send(writer)

        writer.tgwrite_date(self.start_date)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return PhoneCall(None, None, None, None, None, None, None, None, None, None, None)

    def on_response(self, reader):
        self.id = reader.read_long()
        self.access_hash = reader.read_long()
        self.date = reader.tgread_date()
        self.admin_id = reader.read_int()
        self.participant_id = reader.read_int()
        self.g_a_or_b = reader.tgread_bytes()
        self.key_fingerprint = reader.read_long()
        self.protocol = reader.tgread_object()
        self.connection = reader.tgread_object()
        reader.read_int()  # Vector's constructor ID
        self.alternative_connections = []  # Initialize an empty list
        alternative_connections_len = reader.read_int()
        for _ in range(alternative_connections_len):
            alternative_connections_item = reader.tgread_object()
            self.alternative_connections.append(alternative_connections_item)

        self.start_date = reader.tgread_date()

    def __repr__(self):
        return 'phoneCall#ffe6ab67 id:long access_hash:long date:date admin_id:int participant_id:int g_a_or_b:bytes key_fingerprint:long protocol:PhoneCallProtocol connection:PhoneConnection alternative_connections:Vector<PhoneConnection> start_date:date = PhoneCall'

    def __str__(self):
        return '(phoneCall (ID: 0xffe6ab67) = (id={}, access_hash={}, date={}, admin_id={}, participant_id={}, g_a_or_b={}, key_fingerprint={}, protocol={}, connection={}, alternative_connections={}, start_date={}))'.format(str(self.id), str(self.access_hash), str(self.date), str(self.admin_id), str(self.participant_id), str(self.g_a_or_b), str(self.key_fingerprint), str(self.protocol), str(self.connection), None if not self.alternative_connections else [str(_) for _ in self.alternative_connections], str(self.start_date))



from ....tl.mtproto_request import MTProtoRequest


class StickerSet(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    messages.stickerSet#b60a24a6 set:StickerSet packs:Vector<StickerPack> documents:Vector<Document> = messages.StickerSet"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0xb60a24a6

    def __init__(self, set, packs, documents):
        """
        :param set: Telegram type: «StickerSet».
        :param packs: Telegram type: «StickerPack». Must be a list.
        :param documents: Telegram type: «Document». Must be a list.

        Constructor for messages.StickerSet: Instance of StickerSet.
        """
        super().__init__()

        self.set = set
        self.packs = packs
        self.documents = documents

    def on_send(self, writer):
        writer.write_int(StickerSet.constructor_id, signed=False)
        self.set.on_send(writer)
        writer.write_int(0x1cb5c415, signed=False)  # Vector's constructor ID
        writer.write_int(len(self.packs))
        for packs_item in self.packs:
            packs_item.on_send(writer)

        writer.write_int(0x1cb5c415, signed=False)  # Vector's constructor ID
        writer.write_int(len(self.documents))
        for documents_item in self.documents:
            documents_item.on_send(writer)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return StickerSet(None, None, None)

    def on_response(self, reader):
        self.set = reader.tgread_object()
        reader.read_int()  # Vector's constructor ID
        self.packs = []  # Initialize an empty list
        packs_len = reader.read_int()
        for _ in range(packs_len):
            packs_item = reader.tgread_object()
            self.packs.append(packs_item)

        reader.read_int()  # Vector's constructor ID
        self.documents = []  # Initialize an empty list
        documents_len = reader.read_int()
        for _ in range(documents_len):
            documents_item = reader.tgread_object()
            self.documents.append(documents_item)

    def __repr__(self):
        return 'messages.stickerSet#b60a24a6 set:StickerSet packs:Vector<StickerPack> documents:Vector<Document> = messages.StickerSet'

    def __str__(self):
        return '(messages.stickerSet (ID: 0xb60a24a6) = (set={}, packs={}, documents={}))'.format(str(self.set), None if not self.packs else [str(_) for _ in self.packs], None if not self.documents else [str(_) for _ in self.documents])



from ...tl.mtproto_request import MTProtoRequest


class InputPeerNotifySettings(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    inputPeerNotifySettings#38935eb2 flags:# show_previews:flags.0?true silent:flags.1?true mute_until:int sound:string = InputPeerNotifySettings"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x38935eb2

    def __init__(self, mute_until, sound, show_previews=None, silent=None):
        """
        :param show_previews: Telegram type: «true».
        :param silent: Telegram type: «true».
        :param mute_until: Telegram type: «int».
        :param sound: Telegram type: «string».

        Constructor for InputPeerNotifySettings: Instance of InputPeerNotifySettings.
        """
        super().__init__()

        self.show_previews = show_previews
        self.silent = silent
        self.mute_until = mute_until
        self.sound = sound

    def on_send(self, writer):
        writer.write_int(InputPeerNotifySettings.constructor_id, signed=False)
        # Calculate the flags. This equals to those flag arguments which are NOT None
        flags = 0
        flags |= (1 << 0) if self.show_previews else 0
        flags |= (1 << 1) if self.silent else 0
        writer.write_int(flags)

        writer.write_int(self.mute_until)
        writer.tgwrite_string(self.sound)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return InputPeerNotifySettings(None, None, None, None)

    def on_response(self, reader):
        flags = reader.read_int()

        if (flags & (1 << 0)) != 0:
            self.show_previews = True  # Arbitrary not-None value, no need to read since it is a flag

        if (flags & (1 << 1)) != 0:
            self.silent = True  # Arbitrary not-None value, no need to read since it is a flag

        self.mute_until = reader.read_int()
        self.sound = reader.tgread_string()

    def __repr__(self):
        return 'inputPeerNotifySettings#38935eb2 flags:# show_previews:flags.0?true silent:flags.1?true mute_until:int sound:string = InputPeerNotifySettings'

    def __str__(self):
        return '(inputPeerNotifySettings (ID: 0x38935eb2) = (show_previews={}, silent={}, mute_until={}, sound={}))'.format(str(self.show_previews), str(self.silent), str(self.mute_until), str(self.sound))



from .get_messages import GetMessagesRequest
from .get_dialogs import GetDialogsRequest
from .get_history import GetHistoryRequest
from .search import SearchRequest
from .read_history import ReadHistoryRequest
from .delete_history import DeleteHistoryRequest
from .delete_messages import DeleteMessagesRequest
from .received_messages import ReceivedMessagesRequest
from .set_typing import SetTypingRequest
from .send_message import SendMessageRequest
from .send_media import SendMediaRequest
from .forward_messages import ForwardMessagesRequest
from .report_spam import ReportSpamRequest
from .hide_report_spam import HideReportSpamRequest
from .get_peer_settings import GetPeerSettingsRequest
from .get_chats import GetChatsRequest
from .get_full_chat import GetFullChatRequest
from .edit_chat_title import EditChatTitleRequest
from .edit_chat_photo import EditChatPhotoRequest
from .add_chat_user import AddChatUserRequest
from .delete_chat_user import DeleteChatUserRequest
from .create_chat import CreateChatRequest
from .forward_message import ForwardMessageRequest
from .get_dh_config import GetDhConfigRequest
from .request_encryption import RequestEncryptionRequest
from .accept_encryption import AcceptEncryptionRequest
from .discard_encryption import DiscardEncryptionRequest
from .set_encrypted_typing import SetEncryptedTypingRequest
from .read_encrypted_history import ReadEncryptedHistoryRequest
from .send_encrypted import SendEncryptedRequest
from .send_encrypted_file import SendEncryptedFileRequest
from .send_encrypted_service import SendEncryptedServiceRequest
from .received_queue import ReceivedQueueRequest
from .report_encrypted_spam import ReportEncryptedSpamRequest
from .read_message_contents import ReadMessageContentsRequest
from .get_all_stickers import GetAllStickersRequest
from .get_web_page_preview import GetWebPagePreviewRequest
from .export_chat_invite import ExportChatInviteRequest
from .check_chat_invite import CheckChatInviteRequest
from .import_chat_invite import ImportChatInviteRequest
from .get_sticker_set import GetStickerSetRequest
from .install_sticker_set import InstallStickerSetRequest
from .uninstall_sticker_set import UninstallStickerSetRequest
from .start_bot import StartBotRequest
from .get_messages_views import GetMessagesViewsRequest
from .toggle_chat_admins import ToggleChatAdminsRequest
from .edit_chat_admin import EditChatAdminRequest
from .migrate_chat import MigrateChatRequest
from .search_global import SearchGlobalRequest
from .reorder_sticker_sets import ReorderStickerSetsRequest
from .get_document_by_hash import GetDocumentByHashRequest
from .search_gifs import SearchGifsRequest
from .get_saved_gifs import GetSavedGifsRequest
from .save_gif import SaveGifRequest
from .get_inline_bot_results import GetInlineBotResultsRequest
from .set_inline_bot_results import SetInlineBotResultsRequest
from .send_inline_bot_result import SendInlineBotResultRequest
from .get_message_edit_data import GetMessageEditDataRequest
from .edit_message import EditMessageRequest
from .edit_inline_bot_message import EditInlineBotMessageRequest
from .get_bot_callback_answer import GetBotCallbackAnswerRequest
from .set_bot_callback_answer import SetBotCallbackAnswerRequest
from .get_peer_dialogs import GetPeerDialogsRequest
from .save_draft import SaveDraftRequest
from .get_all_drafts import GetAllDraftsRequest
from .get_featured_stickers import GetFeaturedStickersRequest
from .read_featured_stickers import ReadFeaturedStickersRequest
from .get_recent_stickers import GetRecentStickersRequest
from .save_recent_sticker import SaveRecentStickerRequest
from .clear_recent_stickers import ClearRecentStickersRequest
from .get_archived_stickers import GetArchivedStickersRequest
from .get_mask_stickers import GetMaskStickersRequest
from .get_attached_stickers import GetAttachedStickersRequest
from .set_game_score import SetGameScoreRequest
from .set_inline_game_score import SetInlineGameScoreRequest
from .get_game_high_scores import GetGameHighScoresRequest
from .get_inline_game_high_scores import GetInlineGameHighScoresRequest
from .get_common_chats import GetCommonChatsRequest
from .get_all_chats import GetAllChatsRequest
from .get_web_page import GetWebPageRequest
from .toggle_dialog_pin import ToggleDialogPinRequest
from .reorder_pinned_dialogs import ReorderPinnedDialogsRequest
from .get_pinned_dialogs import GetPinnedDialogsRequest
from .set_bot_shipping_results import SetBotShippingResultsRequest
from .set_bot_precheckout_results import SetBotPrecheckoutResultsRequest



from ...tl.mtproto_request import MTProtoRequest


class InputWebDocument(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    inputWebDocument#9bed434d url:string size:int mime_type:string attributes:Vector<DocumentAttribute> = InputWebDocument"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x9bed434d

    def __init__(self, url, size, mime_type, attributes):
        """
        :param url: Telegram type: «string».
        :param size: Telegram type: «int».
        :param mime_type: Telegram type: «string».
        :param attributes: Telegram type: «DocumentAttribute». Must be a list.

        Constructor for InputWebDocument: Instance of InputWebDocument.
        """
        super().__init__()

        self.url = url
        self.size = size
        self.mime_type = mime_type
        self.attributes = attributes

    def on_send(self, writer):
        writer.write_int(InputWebDocument.constructor_id, signed=False)
        writer.tgwrite_string(self.url)
        writer.write_int(self.size)
        writer.tgwrite_string(self.mime_type)
        writer.write_int(0x1cb5c415, signed=False)  # Vector's constructor ID
        writer.write_int(len(self.attributes))
        for attributes_item in self.attributes:
            attributes_item.on_send(writer)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return InputWebDocument(None, None, None, None)

    def on_response(self, reader):
        self.url = reader.tgread_string()
        self.size = reader.read_int()
        self.mime_type = reader.tgread_string()
        reader.read_int()  # Vector's constructor ID
        self.attributes = []  # Initialize an empty list
        attributes_len = reader.read_int()
        for _ in range(attributes_len):
            attributes_item = reader.tgread_object()
            self.attributes.append(attributes_item)

    def __repr__(self):
        return 'inputWebDocument#9bed434d url:string size:int mime_type:string attributes:Vector<DocumentAttribute> = InputWebDocument'

    def __str__(self):
        return '(inputWebDocument (ID: 0x9bed434d) = (url={}, size={}, mime_type={}, attributes={}))'.format(str(self.url), str(self.size), str(self.mime_type), None if not self.attributes else [str(_) for _ in self.attributes])



from ....tl.mtproto_request import MTProtoRequest


class ExportInviteRequest(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    channels.exportInvite#c7560885 channel:InputChannel = ExportedChatInvite"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0xc7560885

    def __init__(self, channel):
        """
        :param channel: Telegram type: «InputChannel».

        :returns ExportedChatInvite: Instance of either ChatInviteEmpty, ChatInviteExported.
        """
        super().__init__()
        self.result = None
        self.confirmed = True  # Confirmed by default

        self.channel = channel

    def on_send(self, writer):
        writer.write_int(ExportInviteRequest.constructor_id, signed=False)
        self.channel.on_send(writer)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return ExportInviteRequest(None)

    def on_response(self, reader):
        self.result = reader.tgread_object()

    def __repr__(self):
        return 'channels.exportInvite#c7560885 channel:InputChannel = ExportedChatInvite'

    def __str__(self):
        return '(channels.exportInvite (ID: 0xc7560885) = (channel={}))'.format(str(self.channel))



from ....tl.mtproto_request import MTProtoRequest


class UpdateDeviceLockedRequest(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    account.updateDeviceLocked#38df3532 period:int = Bool"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x38df3532

    def __init__(self, period):
        """
        :param period: Telegram type: «int».

        :returns Bool: This type has no constructors.
        """
        super().__init__()
        self.result = None
        self.confirmed = True  # Confirmed by default

        self.period = period

    def on_send(self, writer):
        writer.write_int(UpdateDeviceLockedRequest.constructor_id, signed=False)
        writer.write_int(self.period)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return UpdateDeviceLockedRequest(None)

    def on_response(self, reader):
        self.result = reader.tgread_object()

    def __repr__(self):
        return 'account.updateDeviceLocked#38df3532 period:int = Bool'

    def __str__(self):
        return '(account.updateDeviceLocked (ID: 0x38df3532) = (period={}))'.format(str(self.period))



from ...tl.mtproto_request import MTProtoRequest


class InputBotInlineResultPhoto(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    inputBotInlineResultPhoto#a8d864a7 id:string type:string photo:InputPhoto send_message:InputBotInlineMessage = InputBotInlineResult"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0xa8d864a7

    def __init__(self, id, type, photo, send_message):
        """
        :param id: Telegram type: «string».
        :param type: Telegram type: «string».
        :param photo: Telegram type: «InputPhoto».
        :param send_message: Telegram type: «InputBotInlineMessage».

        Constructor for InputBotInlineResult: Instance of either InputBotInlineResult, InputBotInlineResultPhoto, InputBotInlineResultDocument, InputBotInlineResultGame.
        """
        super().__init__()

        self.id = id
        self.type = type
        self.photo = photo
        self.send_message = send_message

    def on_send(self, writer):
        writer.write_int(InputBotInlineResultPhoto.constructor_id, signed=False)
        writer.tgwrite_string(self.id)
        writer.tgwrite_string(self.type)
        self.photo.on_send(writer)
        self.send_message.on_send(writer)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return InputBotInlineResultPhoto(None, None, None, None)

    def on_response(self, reader):
        self.id = reader.tgread_string()
        self.type = reader.tgread_string()
        self.photo = reader.tgread_object()
        self.send_message = reader.tgread_object()

    def __repr__(self):
        return 'inputBotInlineResultPhoto#a8d864a7 id:string type:string photo:InputPhoto send_message:InputBotInlineMessage = InputBotInlineResult'

    def __str__(self):
        return '(inputBotInlineResultPhoto (ID: 0xa8d864a7) = (id={}, type={}, photo={}, send_message={}))'.format(str(self.id), str(self.type), str(self.photo), str(self.send_message))



from .checked_phone import CheckedPhone
from .sent_code import SentCode
from .authorization import Authorization
from .exported_authorization import ExportedAuthorization
from .password_recovery import PasswordRecovery
from .code_type_sms import CodeTypeSms
from .code_type_call import CodeTypeCall
from .code_type_flash_call import CodeTypeFlashCall
from .sent_code_type_app import SentCodeTypeApp
from .sent_code_type_sms import SentCodeTypeSms
from .sent_code_type_call import SentCodeTypeCall
from .sent_code_type_flash_call import SentCodeTypeFlashCall



from ...tl.mtproto_request import MTProtoRequest


class UpdateDraftMessage(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    updateDraftMessage#ee2bb969 peer:Peer draft:DraftMessage = Update"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0xee2bb969

    def __init__(self, peer, draft):
        """
        :param peer: Telegram type: «Peer».
        :param draft: Telegram type: «DraftMessage».

        Constructor for Update: Instance of either UpdateNewMessage, UpdateMessageID, UpdateDeleteMessages, UpdateUserTyping, UpdateChatUserTyping, UpdateChatParticipants, UpdateUserStatus, UpdateUserName, UpdateUserPhoto, UpdateContactRegistered, UpdateContactLink, UpdateNewEncryptedMessage, UpdateEncryptedChatTyping, UpdateEncryption, UpdateEncryptedMessagesRead, UpdateChatParticipantAdd, UpdateChatParticipantDelete, UpdateDcOptions, UpdateUserBlocked, UpdateNotifySettings, UpdateServiceNotification, UpdatePrivacy, UpdateUserPhone, UpdateReadHistoryInbox, UpdateReadHistoryOutbox, UpdateWebPage, UpdateReadMessagesContents, UpdateChannelTooLong, UpdateChannel, UpdateNewChannelMessage, UpdateReadChannelInbox, UpdateDeleteChannelMessages, UpdateChannelMessageViews, UpdateChatAdmins, UpdateChatParticipantAdmin, UpdateNewStickerSet, UpdateStickerSetsOrder, UpdateStickerSets, UpdateSavedGifs, UpdateBotInlineQuery, UpdateBotInlineSend, UpdateEditChannelMessage, UpdateChannelPinnedMessage, UpdateBotCallbackQuery, UpdateEditMessage, UpdateInlineBotCallbackQuery, UpdateReadChannelOutbox, UpdateDraftMessage, UpdateReadFeaturedStickers, UpdateRecentStickers, UpdateConfig, UpdatePtsChanged, UpdateChannelWebPage, UpdateDialogPinned, UpdatePinnedDialogs, UpdateBotWebhookJSON, UpdateBotWebhookJSONQuery, UpdateBotShippingQuery, UpdateBotPrecheckoutQuery, UpdatePhoneCall.
        """
        super().__init__()

        self.peer = peer
        self.draft = draft

    def on_send(self, writer):
        writer.write_int(UpdateDraftMessage.constructor_id, signed=False)
        self.peer.on_send(writer)
        self.draft.on_send(writer)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return UpdateDraftMessage(None, None)

    def on_response(self, reader):
        self.peer = reader.tgread_object()
        self.draft = reader.tgread_object()

    def __repr__(self):
        return 'updateDraftMessage#ee2bb969 peer:Peer draft:DraftMessage = Update'

    def __str__(self):
        return '(updateDraftMessage (ID: 0xee2bb969) = (peer={}, draft={}))'.format(str(self.peer), str(self.draft))



from ....tl.mtproto_request import MTProtoRequest


class State(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    updates.state#a56c2a3e pts:int qts:int date:date seq:int unread_count:int = updates.State"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0xa56c2a3e

    def __init__(self, pts, qts, date, seq, unread_count):
        """
        :param pts: Telegram type: «int».
        :param qts: Telegram type: «int».
        :param date: Telegram type: «date».
        :param seq: Telegram type: «int».
        :param unread_count: Telegram type: «int».

        Constructor for updates.State: Instance of State.
        """
        super().__init__()

        self.pts = pts
        self.qts = qts
        self.date = date
        self.seq = seq
        self.unread_count = unread_count

    def on_send(self, writer):
        writer.write_int(State.constructor_id, signed=False)
        writer.write_int(self.pts)
        writer.write_int(self.qts)
        writer.tgwrite_date(self.date)
        writer.write_int(self.seq)
        writer.write_int(self.unread_count)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return State(None, None, None, None, None)

    def on_response(self, reader):
        self.pts = reader.read_int()
        self.qts = reader.read_int()
        self.date = reader.tgread_date()
        self.seq = reader.read_int()
        self.unread_count = reader.read_int()

    def __repr__(self):
        return 'updates.state#a56c2a3e pts:int qts:int date:date seq:int unread_count:int = updates.State'

    def __str__(self):
        return '(updates.state (ID: 0xa56c2a3e) = (pts={}, qts={}, date={}, seq={}, unread_count={}))'.format(str(self.pts), str(self.qts), str(self.date), str(self.seq), str(self.unread_count))



from ....tl.mtproto_request import MTProtoRequest


class GetMessageEditDataRequest(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    messages.getMessageEditData#fda68d36 peer:InputPeer id:int = messages.MessageEditData"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0xfda68d36

    def __init__(self, peer, id):
        """
        :param peer: Telegram type: «InputPeer».
        :param id: Telegram type: «int».

        :returns messages.MessageEditData: Instance of MessageEditData.
        """
        super().__init__()
        self.result = None
        self.confirmed = True  # Confirmed by default

        self.peer = peer
        self.id = id

    def on_send(self, writer):
        writer.write_int(GetMessageEditDataRequest.constructor_id, signed=False)
        self.peer.on_send(writer)
        writer.write_int(self.id)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return GetMessageEditDataRequest(None, None)

    def on_response(self, reader):
        self.result = reader.tgread_object()

    def __repr__(self):
        return 'messages.getMessageEditData#fda68d36 peer:InputPeer id:int = messages.MessageEditData'

    def __str__(self):
        return '(messages.getMessageEditData (ID: 0xfda68d36) = (peer={}, id={}))'.format(str(self.peer), str(self.id))



from ....tl.mtproto_request import MTProtoRequest


class SentCode(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    auth.sentCode#5e002502 flags:# phone_registered:flags.0?true type:auth.SentCodeType phone_code_hash:string next_type:flags.1?auth.CodeType timeout:flags.2?int = auth.SentCode"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x5e002502

    def __init__(self, type, phone_code_hash, phone_registered=None, next_type=None, timeout=None):
        """
        :param phone_registered: Telegram type: «true».
        :param type: Telegram type: «auth.SentCodeType».
        :param phone_code_hash: Telegram type: «string».
        :param next_type: Telegram type: «auth.CodeType».
        :param timeout: Telegram type: «int».

        Constructor for auth.SentCode: Instance of SentCode.
        """
        super().__init__()

        self.phone_registered = phone_registered
        self.type = type
        self.phone_code_hash = phone_code_hash
        self.next_type = next_type
        self.timeout = timeout

    def on_send(self, writer):
        writer.write_int(SentCode.constructor_id, signed=False)
        # Calculate the flags. This equals to those flag arguments which are NOT None
        flags = 0
        flags |= (1 << 0) if self.phone_registered else 0
        flags |= (1 << 1) if self.next_type else 0
        flags |= (1 << 2) if self.timeout else 0
        writer.write_int(flags)

        self.type.on_send(writer)
        writer.tgwrite_string(self.phone_code_hash)
        if self.next_type:
            self.next_type.on_send(writer)

        if self.timeout:
            writer.write_int(self.timeout)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return SentCode(None, None, None, None, None)

    def on_response(self, reader):
        flags = reader.read_int()

        if (flags & (1 << 0)) != 0:
            self.phone_registered = True  # Arbitrary not-None value, no need to read since it is a flag

        self.type = reader.tgread_object()
        self.phone_code_hash = reader.tgread_string()
        if (flags & (1 << 1)) != 0:
            self.next_type = reader.tgread_object()

        if (flags & (1 << 2)) != 0:
            self.timeout = reader.read_int()

    def __repr__(self):
        return 'auth.sentCode#5e002502 flags:# phone_registered:flags.0?true type:auth.SentCodeType phone_code_hash:string next_type:flags.1?auth.CodeType timeout:flags.2?int = auth.SentCode'

    def __str__(self):
        return '(auth.sentCode (ID: 0x5e002502) = (phone_registered={}, type={}, phone_code_hash={}, next_type={}, timeout={}))'.format(str(self.phone_registered), str(self.type), str(self.phone_code_hash), str(self.next_type), str(self.timeout))



from ....tl.mtproto_request import MTProtoRequest


class StartBotRequest(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    messages.startBot#e6df7378 bot:InputUser peer:InputPeer random_id:long start_param:string = Updates"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0xe6df7378

    def __init__(self, bot, peer, random_id, start_param):
        """
        :param bot: Telegram type: «InputUser».
        :param peer: Telegram type: «InputPeer».
        :param random_id: Telegram type: «long».
        :param start_param: Telegram type: «string».

        :returns Updates: Instance of either UpdatesTooLong, UpdateShortMessage, UpdateShortChatMessage, UpdateShort, UpdatesCombined, UpdatesTg, UpdateShortSentMessage.
        """
        super().__init__()
        self.result = None
        self.confirmed = True  # Confirmed by default

        self.bot = bot
        self.peer = peer
        self.random_id = random_id
        self.start_param = start_param

    def on_send(self, writer):
        writer.write_int(StartBotRequest.constructor_id, signed=False)
        self.bot.on_send(writer)
        self.peer.on_send(writer)
        writer.write_long(self.random_id)
        writer.tgwrite_string(self.start_param)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return StartBotRequest(None, None, None, None)

    def on_response(self, reader):
        self.result = reader.tgread_object()

    def __repr__(self):
        return 'messages.startBot#e6df7378 bot:InputUser peer:InputPeer random_id:long start_param:string = Updates'

    def __str__(self):
        return '(messages.startBot (ID: 0xe6df7378) = (bot={}, peer={}, random_id={}, start_param={}))'.format(str(self.bot), str(self.peer), str(self.random_id), str(self.start_param))



from ...tl.mtproto_request import MTProtoRequest


class UpdateBotWebhookJSON(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    updateBotWebhookJSON#8317c0c3 data:DataJSON = Update"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x8317c0c3

    def __init__(self, data):
        """
        :param data: Telegram type: «DataJSON».

        Constructor for Update: Instance of either UpdateNewMessage, UpdateMessageID, UpdateDeleteMessages, UpdateUserTyping, UpdateChatUserTyping, UpdateChatParticipants, UpdateUserStatus, UpdateUserName, UpdateUserPhoto, UpdateContactRegistered, UpdateContactLink, UpdateNewEncryptedMessage, UpdateEncryptedChatTyping, UpdateEncryption, UpdateEncryptedMessagesRead, UpdateChatParticipantAdd, UpdateChatParticipantDelete, UpdateDcOptions, UpdateUserBlocked, UpdateNotifySettings, UpdateServiceNotification, UpdatePrivacy, UpdateUserPhone, UpdateReadHistoryInbox, UpdateReadHistoryOutbox, UpdateWebPage, UpdateReadMessagesContents, UpdateChannelTooLong, UpdateChannel, UpdateNewChannelMessage, UpdateReadChannelInbox, UpdateDeleteChannelMessages, UpdateChannelMessageViews, UpdateChatAdmins, UpdateChatParticipantAdmin, UpdateNewStickerSet, UpdateStickerSetsOrder, UpdateStickerSets, UpdateSavedGifs, UpdateBotInlineQuery, UpdateBotInlineSend, UpdateEditChannelMessage, UpdateChannelPinnedMessage, UpdateBotCallbackQuery, UpdateEditMessage, UpdateInlineBotCallbackQuery, UpdateReadChannelOutbox, UpdateDraftMessage, UpdateReadFeaturedStickers, UpdateRecentStickers, UpdateConfig, UpdatePtsChanged, UpdateChannelWebPage, UpdateDialogPinned, UpdatePinnedDialogs, UpdateBotWebhookJSON, UpdateBotWebhookJSONQuery, UpdateBotShippingQuery, UpdateBotPrecheckoutQuery, UpdatePhoneCall.
        """
        super().__init__()

        self.data = data

    def on_send(self, writer):
        writer.write_int(UpdateBotWebhookJSON.constructor_id, signed=False)
        self.data.on_send(writer)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return UpdateBotWebhookJSON(None)

    def on_response(self, reader):
        self.data = reader.tgread_object()

    def __repr__(self):
        return 'updateBotWebhookJSON#8317c0c3 data:DataJSON = Update'

    def __str__(self):
        return '(updateBotWebhookJSON (ID: 0x8317c0c3) = (data={}))'.format(str(self.data))



from ...tl.mtproto_request import MTProtoRequest


class UpdateUserPhoto(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    updateUserPhoto#95313b0c user_id:int date:date photo:UserProfilePhoto previous:Bool = Update"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x95313b0c

    def __init__(self, user_id, date, photo, previous):
        """
        :param user_id: Telegram type: «int».
        :param date: Telegram type: «date».
        :param photo: Telegram type: «UserProfilePhoto».
        :param previous: Telegram type: «Bool».

        Constructor for Update: Instance of either UpdateNewMessage, UpdateMessageID, UpdateDeleteMessages, UpdateUserTyping, UpdateChatUserTyping, UpdateChatParticipants, UpdateUserStatus, UpdateUserName, UpdateUserPhoto, UpdateContactRegistered, UpdateContactLink, UpdateNewEncryptedMessage, UpdateEncryptedChatTyping, UpdateEncryption, UpdateEncryptedMessagesRead, UpdateChatParticipantAdd, UpdateChatParticipantDelete, UpdateDcOptions, UpdateUserBlocked, UpdateNotifySettings, UpdateServiceNotification, UpdatePrivacy, UpdateUserPhone, UpdateReadHistoryInbox, UpdateReadHistoryOutbox, UpdateWebPage, UpdateReadMessagesContents, UpdateChannelTooLong, UpdateChannel, UpdateNewChannelMessage, UpdateReadChannelInbox, UpdateDeleteChannelMessages, UpdateChannelMessageViews, UpdateChatAdmins, UpdateChatParticipantAdmin, UpdateNewStickerSet, UpdateStickerSetsOrder, UpdateStickerSets, UpdateSavedGifs, UpdateBotInlineQuery, UpdateBotInlineSend, UpdateEditChannelMessage, UpdateChannelPinnedMessage, UpdateBotCallbackQuery, UpdateEditMessage, UpdateInlineBotCallbackQuery, UpdateReadChannelOutbox, UpdateDraftMessage, UpdateReadFeaturedStickers, UpdateRecentStickers, UpdateConfig, UpdatePtsChanged, UpdateChannelWebPage, UpdateDialogPinned, UpdatePinnedDialogs, UpdateBotWebhookJSON, UpdateBotWebhookJSONQuery, UpdateBotShippingQuery, UpdateBotPrecheckoutQuery, UpdatePhoneCall.
        """
        super().__init__()

        self.user_id = user_id
        self.date = date
        self.photo = photo
        self.previous = previous

    def on_send(self, writer):
        writer.write_int(UpdateUserPhoto.constructor_id, signed=False)
        writer.write_int(self.user_id)
        writer.tgwrite_date(self.date)
        self.photo.on_send(writer)
        writer.tgwrite_bool(self.previous)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return UpdateUserPhoto(None, None, None, None)

    def on_response(self, reader):
        self.user_id = reader.read_int()
        self.date = reader.tgread_date()
        self.photo = reader.tgread_object()
        self.previous = reader.tgread_bool()

    def __repr__(self):
        return 'updateUserPhoto#95313b0c user_id:int date:date photo:UserProfilePhoto previous:Bool = Update'

    def __str__(self):
        return '(updateUserPhoto (ID: 0x95313b0c) = (user_id={}, date={}, photo={}, previous={}))'.format(str(self.user_id), str(self.date), str(self.photo), str(self.previous))



from ...tl.mtproto_request import MTProtoRequest


class ChannelParticipantCreator(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    channelParticipantCreator#e3e2e1f9 user_id:int = ChannelParticipant"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0xe3e2e1f9

    def __init__(self, user_id):
        """
        :param user_id: Telegram type: «int».

        Constructor for ChannelParticipant: Instance of either ChannelParticipant, ChannelParticipantSelf, ChannelParticipantModerator, ChannelParticipantEditor, ChannelParticipantKicked, ChannelParticipantCreator.
        """
        super().__init__()

        self.user_id = user_id

    def on_send(self, writer):
        writer.write_int(ChannelParticipantCreator.constructor_id, signed=False)
        writer.write_int(self.user_id)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return ChannelParticipantCreator(None)

    def on_response(self, reader):
        self.user_id = reader.read_int()

    def __repr__(self):
        return 'channelParticipantCreator#e3e2e1f9 user_id:int = ChannelParticipant'

    def __str__(self):
        return '(channelParticipantCreator (ID: 0xe3e2e1f9) = (user_id={}))'.format(str(self.user_id))
